/*
Package gosdnyang is a generated package which contains definitions
of structs which represent a YANG schema. The generated schema can be
compressed by a series of transformations (compression was false
in this case).

This package was generated by /Users/mk/go/pkg/mod/github.com/openconfig/ygot@v0.8.7/genutil/names.go
using the following YANG input files:
	- yang/ciena-waveserver-interfaces.yang
Imported modules were sourced from:
	- yang/...
*/
package ciena

import (
	"encoding/json"
	"fmt"
	"reflect"

	"github.com/openconfig/ygot/ygot"
	"github.com/openconfig/goyang/pkg/yang"
	"github.com/openconfig/ygot/ytypes"
)

// Binary is a type that is used for fields that have a YANG type of
// binary. It is used such that binary fields can be distinguished from
// leaf-lists of uint8s (which are mapped to []uint8, equivalent to
// []byte in reflection).
type Binary []byte

// YANGEmpty is a type that is used for fields that have a YANG type of
// empty. It is used such that empty fields can be distinguished from boolean fields
// in the generated code.
type YANGEmpty bool

var (
	SchemaTree map[string]*yang.Entry
)

func init() {
	var err error
	if SchemaTree, err = UnzipSchema(); err != nil {
		panic("schema error: " +  err.Error())
	}
}

// Schema returns the details of the generated schema.
func Schema() (*ytypes.Schema, error) {
	uzp, err := UnzipSchema()
	if err != nil {
		return nil, fmt.Errorf("cannot unzip schema, %v", err)
	}

	return &ytypes.Schema{
		Root: &Device{},
		SchemaTree: uzp,
		Unmarshal: Unmarshal,
	}, nil
}

// UnzipSchema unzips the zipped schema and returns a map of yang.Entry nodes,
// keyed by the name of the struct that the yang.Entry describes the schema for.
func UnzipSchema() (map[string]*yang.Entry, error) {
	var schemaTree map[string]*yang.Entry
	var err error
	if schemaTree, err = ygot.GzipToSchema(ySchema); err != nil {
		return nil, fmt.Errorf("could not unzip the schema; %v", err)
	}
	return schemaTree, nil
}

// Unmarshal unmarshals data, which must be RFC7951 JSON format, into
// destStruct, which must be non-nil and the correct GoStruct type. It returns
// an error if the destStruct is not found in the schema or the data cannot be
// unmarshaled. The supplied options (opts) are used to control the behaviour
// of the unmarshal function - for example, determining whether errors are
// thrown for unknown fields in the input JSON.
func Unmarshal(data []byte, destStruct ygot.GoStruct, opts ...ytypes.UnmarshalOpt) error {
	tn := reflect.TypeOf(destStruct).Elem().Name()
	schema, ok := SchemaTree[tn]
	if !ok {
		return fmt.Errorf("could not find schema for type %s", tn )
	}
	var jsonTree interface{}
	if err := json.Unmarshal([]byte(data), &jsonTree); err != nil {
		return err
	}
	return ytypes.Unmarshal(schema, destStruct, jsonTree, opts...)
}

// CienaWaveserverInterfaces_WaveserverInterfaces represents the /ciena-waveserver-interfaces/waveserver-interfaces YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces struct {
	Acl	*CienaWaveserverInterfaces_WaveserverInterfaces_Acl	`path:"acl" module:"ciena-waveserver-interfaces"`
	Bgp	*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp	`path:"bgp" module:"ciena-waveserver-interfaces"`
	LogicalInterface	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface	`path:"logical-interface" module:"ciena-waveserver-interfaces"`
	PhysicalInterface	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface	`path:"physical-interface" module:"ciena-waveserver-interfaces"`
	Routes	*CienaWaveserverInterfaces_WaveserverInterfaces_Routes	`path:"routes" module:"ciena-waveserver-interfaces"`
	Stacks	*CienaWaveserverInterfaces_WaveserverInterfaces_Stacks	`path:"stacks" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces) IsYANGGoStruct() {}

// NewLogicalInterface creates a new entry in the LogicalInterface list of the
// CienaWaveserverInterfaces_WaveserverInterfaces struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces) NewLogicalInterface(Name string) (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LogicalInterface == nil {
		t.LogicalInterface = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LogicalInterface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LogicalInterface", key)
	}

	t.LogicalInterface[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface{
		Name: &Name,
	}

	return t.LogicalInterface[key], nil
}

// NewPhysicalInterface creates a new entry in the PhysicalInterface list of the
// CienaWaveserverInterfaces_WaveserverInterfaces struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces) NewPhysicalInterface(Name string) (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PhysicalInterface == nil {
		t.PhysicalInterface = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PhysicalInterface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PhysicalInterface", key)
	}

	t.PhysicalInterface[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface{
		Name: &Name,
	}

	return t.PhysicalInterface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Acl represents the /ciena-waveserver-interfaces/waveserver-interfaces/acl YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Acl struct {
	Ipv4AclEntry	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry	`path:"ipv4-acl-entry" module:"ciena-waveserver-interfaces"`
	Ipv6AclEntry	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry	`path:"ipv6-acl-entry" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Acl implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl) IsYANGGoStruct() {}

// NewIpv4AclEntry creates a new entry in the Ipv4AclEntry list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Acl struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl) NewIpv4AclEntry(Index uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4AclEntry == nil {
		t.Ipv4AclEntry = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4AclEntry", key)
	}

	t.Ipv4AclEntry[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry{
		Index: &Index,
	}

	return t.Ipv4AclEntry[key], nil
}

// NewIpv6AclEntry creates a new entry in the Ipv6AclEntry list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Acl struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl) NewIpv6AclEntry(Index uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6AclEntry == nil {
		t.Ipv6AclEntry = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6AclEntry", key)
	}

	t.Ipv6AclEntry[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry{
		Index: &Index,
	}

	return t.Ipv6AclEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Acl"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry represents the /ciena-waveserver-interfaces/waveserver-interfaces/acl/ipv4-acl-entry YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry struct {
	Index	*uint32	`path:"index" module:"ciena-waveserver-interfaces"`
	Properties	*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties	`path:"properties" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties represents the /ciena-waveserver-interfaces/waveserver-interfaces/acl/ipv4-acl-entry/properties YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties struct {
	Action	E_CienaWaveserverInterfaces_AclAction	`path:"action" module:"ciena-waveserver-interfaces"`
	DestinationIpAddress	*string	`path:"destination-ip-address" module:"ciena-waveserver-interfaces"`
	DestinationPort	*uint16	`path:"destination-port" module:"ciena-waveserver-interfaces"`
	Protocol	*uint8	`path:"protocol" module:"ciena-waveserver-interfaces"`
	SourceIpAddress	*string	`path:"source-ip-address" module:"ciena-waveserver-interfaces"`
	SourcePort	*uint16	`path:"source-port" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv4AclEntry_Properties) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry represents the /ciena-waveserver-interfaces/waveserver-interfaces/acl/ipv6-acl-entry YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry struct {
	Index	*uint32	`path:"index" module:"ciena-waveserver-interfaces"`
	Properties	*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties	`path:"properties" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties represents the /ciena-waveserver-interfaces/waveserver-interfaces/acl/ipv6-acl-entry/properties YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties struct {
	Action	E_CienaWaveserverInterfaces_AclAction	`path:"action" module:"ciena-waveserver-interfaces"`
	DestinationIpAddress	*string	`path:"destination-ip-address" module:"ciena-waveserver-interfaces"`
	DestinationPort	*uint16	`path:"destination-port" module:"ciena-waveserver-interfaces"`
	Protocol	*uint8	`path:"protocol" module:"ciena-waveserver-interfaces"`
	SourceIpAddress	*string	`path:"source-ip-address" module:"ciena-waveserver-interfaces"`
	SourcePort	*uint16	`path:"source-port" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Acl_Ipv6AclEntry_Properties) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp struct {
	Peer	map[E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer	`path:"peer" module:"ciena-waveserver-interfaces"`
	Properties	*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties	`path:"properties" module:"ciena-waveserver-interfaces"`
	RuntimeRoutes	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes	`path:"runtime-routes" module:"ciena-waveserver-interfaces"`
	State	*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State	`path:"state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp) IsYANGGoStruct() {}

// NewPeer creates a new entry in the Peer list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp) NewPeer(Name E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name) (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Peer == nil {
		t.Peer = make(map[E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Peer[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Peer", key)
	}

	t.Peer[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer{
		Name: Name,
	}

	return t.Peer[key], nil
}

// NewRuntimeRoutes creates a new entry in the RuntimeRoutes list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp) NewRuntimeRoutes(RouteIndex uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RuntimeRoutes == nil {
		t.RuntimeRoutes = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes)
	}

	key := RouteIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RuntimeRoutes[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RuntimeRoutes", key)
	}

	t.RuntimeRoutes[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes{
		RouteIndex: &RouteIndex,
	}

	return t.RuntimeRoutes[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/peer YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer struct {
	AdvertisedRoutes	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes	`path:"advertised-routes" module:"ciena-waveserver-interfaces"`
	AutonomousSystem	*uint32	`path:"autonomous-system" module:"ciena-waveserver-interfaces"`
	Interface	*string	`path:"interface" module:"ciena-waveserver-interfaces"`
	Ip	*string	`path:"ip" module:"ciena-waveserver-interfaces"`
	MessagesReceived	*uint32	`path:"messages-received" module:"ciena-waveserver-interfaces"`
	MessagesSent	*uint32	`path:"messages-sent" module:"ciena-waveserver-interfaces"`
	Name	E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name	`path:"name" module:"ciena-waveserver-interfaces"`
	OperationalState	E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState	`path:"operational-state" module:"ciena-waveserver-interfaces"`
	ReceivedRoutes	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes	`path:"received-routes" module:"ciena-waveserver-interfaces"`
	UpTime	*string	`path:"up-time" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) IsYANGGoStruct() {}

// NewAdvertisedRoutes creates a new entry in the AdvertisedRoutes list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) NewAdvertisedRoutes(RouteIndex uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdvertisedRoutes == nil {
		t.AdvertisedRoutes = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes)
	}

	key := RouteIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdvertisedRoutes[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdvertisedRoutes", key)
	}

	t.AdvertisedRoutes[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes{
		RouteIndex: &RouteIndex,
	}

	return t.AdvertisedRoutes[key], nil
}

// NewReceivedRoutes creates a new entry in the ReceivedRoutes list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) NewReceivedRoutes(RouteIndex uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ReceivedRoutes == nil {
		t.ReceivedRoutes = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes)
	}

	key := RouteIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ReceivedRoutes[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ReceivedRoutes", key)
	}

	t.ReceivedRoutes[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes{
		RouteIndex: &RouteIndex,
	}

	return t.ReceivedRoutes[key], nil
}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"name": t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/peer/advertised-routes YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes struct {
	LocalPreference	*int32	`path:"local-preference" module:"ciena-waveserver-interfaces"`
	Metric	*int32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Network	*string	`path:"network" module:"ciena-waveserver-interfaces"`
	NextHop	*string	`path:"next-hop" module:"ciena-waveserver-interfaces"`
	Path	*string	`path:"path" module:"ciena-waveserver-interfaces"`
	RouteIndex	*uint32	`path:"route-index" module:"ciena-waveserver-interfaces"`
	Weight	*int32	`path:"weight" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RouteIndex == nil {
		return nil, fmt.Errorf("nil value for key RouteIndex")
	}

	return map[string]interface{}{
		"route-index": *t.RouteIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_AdvertisedRoutes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/peer/received-routes YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes struct {
	LocalPreference	*int32	`path:"local-preference" module:"ciena-waveserver-interfaces"`
	Metric	*int32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Network	*string	`path:"network" module:"ciena-waveserver-interfaces"`
	NextHop	*string	`path:"next-hop" module:"ciena-waveserver-interfaces"`
	Path	*string	`path:"path" module:"ciena-waveserver-interfaces"`
	RouteIndex	*uint32	`path:"route-index" module:"ciena-waveserver-interfaces"`
	Weight	*int32	`path:"weight" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RouteIndex == nil {
		return nil, fmt.Errorf("nil value for key RouteIndex")
	}

	return map[string]interface{}{
		"route-index": *t.RouteIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_ReceivedRoutes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/properties YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties struct {
	AdvertisedNetwork	*string	`path:"advertised-network" module:"ciena-waveserver-interfaces"`
	AutonomousSystem	*uint32	`path:"autonomous-system" module:"ciena-waveserver-interfaces"`
	HoldoffTime	*uint16	`path:"holdoff-time" module:"ciena-waveserver-interfaces"`
	KeepAliveTime	*uint16	`path:"keep-alive-time" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Properties) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/runtime-routes YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes struct {
	Gateway	*string	`path:"gateway" module:"ciena-waveserver-interfaces"`
	Interface	*string	`path:"interface" module:"ciena-waveserver-interfaces"`
	Prefix	*string	`path:"prefix" module:"ciena-waveserver-interfaces"`
	RouteIndex	*uint32	`path:"route-index" module:"ciena-waveserver-interfaces"`
	Type	*string	`path:"type" module:"ciena-waveserver-interfaces"`
	UpTime	*string	`path:"up-time" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RouteIndex == nil {
		return nil, fmt.Errorf("nil value for key RouteIndex")
	}

	return map[string]interface{}{
		"route-index": *t.RouteIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_RuntimeRoutes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State represents the /ciena-waveserver-interfaces/waveserver-interfaces/bgp/state YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State struct {
	AdminState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"admin-state" module:"ciena-waveserver-interfaces"`
	OperationalState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"operational-state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_State) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface struct {
	Id	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id	`path:"id" module:"ciena-waveserver-interfaces"`
	InbandIfNeighborStatus	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus	`path:"inband-if-neighbor-status" module:"ciena-waveserver-interfaces"`
	Name	*string	`path:"name" module:"ciena-waveserver-interfaces"`
	Properties	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties	`path:"properties" module:"ciena-waveserver-interfaces"`
	State	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State	`path:"state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/id YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id struct {
	AssociatedPhysicalInterface	[]string	`path:"associated-physical-interface" module:"ciena-waveserver-interfaces"`
	Bgp	*bool	`path:"bgp" module:"ciena-waveserver-interfaces"`
	Ifindex	*uint32	`path:"ifindex" module:"ciena-waveserver-interfaces"`
	Internal	*bool	`path:"internal" module:"ciena-waveserver-interfaces"`
	Name	*string	`path:"name" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Id) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/inband-if-neighbor-status YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus struct {
	Ipv4NeighborRouterId	*string	`path:"ipv4-neighbor-router-id" module:"ciena-waveserver-interfaces"`
	Ipv4OperationalState	E_CienaWaveserverInterfaces_UpDownEnum	`path:"ipv4-operational-state" module:"ciena-waveserver-interfaces"`
	Ipv6NeighborRouterId	*string	`path:"ipv6-neighbor-router-id" module:"ciena-waveserver-interfaces"`
	Ipv6OperationalState	E_CienaWaveserverInterfaces_UpDownEnum	`path:"ipv6-operational-state" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_InbandIfNeighborStatus) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties struct {
	Ipv4	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4	`path:"ipv4" module:"ciena-waveserver-interfaces"`
	Ipv6	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6	`path:"ipv6" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4 represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv4 YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4 struct {
	AdminState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"admin-state" module:"ciena-waveserver-interfaces"`
	ApipaIpAddress	*string	`path:"apipa-ip-address" module:"ciena-waveserver-interfaces"`
	BackupGateway	*string	`path:"backup-gateway" module:"ciena-waveserver-interfaces"`
	DhcpGateway	*string	`path:"dhcp-gateway" module:"ciena-waveserver-interfaces"`
	DhcpIpAddress	*string	`path:"dhcp-ip-address" module:"ciena-waveserver-interfaces"`
	OperGateway	*string	`path:"oper-gateway" module:"ciena-waveserver-interfaces"`
	OperIpAddress	*string	`path:"oper-ip-address" module:"ciena-waveserver-interfaces"`
	UserGateway	*string	`path:"user-gateway" module:"ciena-waveserver-interfaces"`
	UserIpAddress	*string	`path:"user-ip-address" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv6 YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 struct {
	GatewayConfiguration	*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration	`path:"gateway-configuration" module:"ciena-waveserver-interfaces"`
	OperGateway	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway	`path:"oper-gateway" module:"ciena-waveserver-interfaces"`
	OperIpAddress	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress	`path:"oper-ip-address" module:"ciena-waveserver-interfaces"`
	UserIpAddress	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress	`path:"user-ip-address" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) IsYANGGoStruct() {}

// NewOperGateway creates a new entry in the OperGateway list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) NewOperGateway(IpAddress string) (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.OperGateway == nil {
		t.OperGateway = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway)
	}

	key := IpAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.OperGateway[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list OperGateway", key)
	}

	t.OperGateway[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway{
		IpAddress: &IpAddress,
	}

	return t.OperGateway[key], nil
}

// NewOperIpAddress creates a new entry in the OperIpAddress list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) NewOperIpAddress(IpAddress string) (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.OperIpAddress == nil {
		t.OperIpAddress = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress)
	}

	key := IpAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.OperIpAddress[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list OperIpAddress", key)
	}

	t.OperIpAddress[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress{
		IpAddress: &IpAddress,
	}

	return t.OperIpAddress[key], nil
}

// NewUserIpAddress creates a new entry in the UserIpAddress list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6 struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) NewUserIpAddress(IpAddress string) (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UserIpAddress == nil {
		t.UserIpAddress = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress)
	}

	key := IpAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UserIpAddress[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UserIpAddress", key)
	}

	t.UserIpAddress[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress{
		IpAddress: &IpAddress,
	}

	return t.UserIpAddress[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv6/gateway-configuration YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration struct {
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
	OperationalState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"operational-state" module:"ciena-waveserver-interfaces"`
	Source	E_CienaWaveserverInterfaces_IpAddressType	`path:"source" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_GatewayConfiguration) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv6/oper-gateway YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway struct {
	InterfaceName	*string	`path:"interface-name" module:"ciena-waveserver-interfaces"`
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Source	E_CienaWaveserverInterfaces_IpAddressType	`path:"source" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway) ΛListKeyMap() (map[string]interface{}, error) {
	if t.IpAddress == nil {
		return nil, fmt.Errorf("nil value for key IpAddress")
	}

	return map[string]interface{}{
		"ip-address": *t.IpAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperGateway) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv6/oper-ip-address YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress struct {
	DadFailure	*bool	`path:"dad-failure" module:"ciena-waveserver-interfaces"`
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
	Source	E_CienaWaveserverInterfaces_IpAddressType	`path:"source" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress) ΛListKeyMap() (map[string]interface{}, error) {
	if t.IpAddress == nil {
		return nil, fmt.Errorf("nil value for key IpAddress")
	}

	return map[string]interface{}{
		"ip-address": *t.IpAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_OperIpAddress) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/properties/ipv6/user-ip-address YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress struct {
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress) ΛListKeyMap() (map[string]interface{}, error) {
	if t.IpAddress == nil {
		return nil, fmt.Errorf("nil value for key IpAddress")
	}

	return map[string]interface{}{
		"ip-address": *t.IpAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_Properties_Ipv6_UserIpAddress) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State represents the /ciena-waveserver-interfaces/waveserver-interfaces/logical-interface/state YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State struct {
	AdminState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"admin-state" module:"ciena-waveserver-interfaces"`
	OperationalState	E_CienaWaveserverInterfaces_UpDownEnum	`path:"operational-state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_LogicalInterface_State) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface represents the /ciena-waveserver-interfaces/waveserver-interfaces/physical-interface YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface struct {
	Id	*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id	`path:"id" module:"ciena-waveserver-interfaces"`
	Name	*string	`path:"name" module:"ciena-waveserver-interfaces"`
	Properties	*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties	`path:"properties" module:"ciena-waveserver-interfaces"`
	State	*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State	`path:"state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id represents the /ciena-waveserver-interfaces/waveserver-interfaces/physical-interface/id YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id struct {
	Ifindex	*uint32	`path:"ifindex" module:"ciena-waveserver-interfaces"`
	Name	*string	`path:"name" module:"ciena-waveserver-interfaces"`
	Type	E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type	`path:"type" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties represents the /ciena-waveserver-interfaces/waveserver-interfaces/physical-interface/properties YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties struct {
	Ethernet	*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet	`path:"ethernet" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet represents the /ciena-waveserver-interfaces/waveserver-interfaces/physical-interface/properties/ethernet YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet struct {
	AutoNegotiation	*bool	`path:"auto-negotiation" module:"ciena-waveserver-interfaces"`
	Duplex	E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex	`path:"duplex" module:"ciena-waveserver-interfaces"`
	FlowControl	*bool	`path:"flow-control" module:"ciena-waveserver-interfaces"`
	MacAddress	*string	`path:"mac-address" module:"ciena-waveserver-interfaces"`
	Speed	E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed	`path:"speed" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State represents the /ciena-waveserver-interfaces/waveserver-interfaces/physical-interface/state YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State struct {
	AdminState	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"admin-state" module:"ciena-waveserver-interfaces"`
	OperationalState	E_CienaWaveserverInterfaces_UpDownEnum	`path:"operational-state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_State) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes struct {
	Ipv4DynamicRoute	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute	`path:"ipv4-dynamic-route" module:"ciena-waveserver-interfaces"`
	Ipv4StaticRoute	map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute	`path:"ipv4-static-route" module:"ciena-waveserver-interfaces"`
	Ipv6DynamicRoute	map[CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute_Key]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute	`path:"ipv6-dynamic-route" module:"ciena-waveserver-interfaces"`
	Ipv6StaticRoute	map[CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute_Key]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute	`path:"ipv6-static-route" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes) IsYANGGoStruct() {}

// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute_Key represents the key for list Ipv6DynamicRoute of element /ciena-waveserver-interfaces/waveserver-interfaces/routes.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute_Key struct {
	Destination	string	`path:"destination"`
	Gateway	string	`path:"gateway"`
	Metric	uint32	`path:"metric"`
}

// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute_Key represents the key for list Ipv6StaticRoute of element /ciena-waveserver-interfaces/waveserver-interfaces/routes.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute_Key struct {
	Destination	string	`path:"destination"`
	Gateway	string	`path:"gateway"`
	Metric	uint32	`path:"metric"`
}

// NewIpv4DynamicRoute creates a new entry in the Ipv4DynamicRoute list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) NewIpv4DynamicRoute(Destination string) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4DynamicRoute == nil {
		t.Ipv4DynamicRoute = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute)
	}

	key := Destination

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4DynamicRoute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4DynamicRoute", key)
	}

	t.Ipv4DynamicRoute[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute{
		Destination: &Destination,
	}

	return t.Ipv4DynamicRoute[key], nil
}

// NewIpv4StaticRoute creates a new entry in the Ipv4StaticRoute list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) NewIpv4StaticRoute(Destination string) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4StaticRoute == nil {
		t.Ipv4StaticRoute = make(map[string]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute)
	}

	key := Destination

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4StaticRoute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4StaticRoute", key)
	}

	t.Ipv4StaticRoute[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute{
		Destination: &Destination,
	}

	return t.Ipv4StaticRoute[key], nil
}

// NewIpv6DynamicRoute creates a new entry in the Ipv6DynamicRoute list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) NewIpv6DynamicRoute(Destination string, Gateway string, Metric uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6DynamicRoute == nil {
		t.Ipv6DynamicRoute = make(map[CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute_Key]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute)
	}

	key := CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute_Key{
		Destination: Destination,
		Gateway: Gateway,
		Metric: Metric,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6DynamicRoute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6DynamicRoute", key)
	}

	t.Ipv6DynamicRoute[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute{
		Destination: &Destination,
		Gateway: &Gateway,
		Metric: &Metric,
	}

	return t.Ipv6DynamicRoute[key], nil
}

// NewIpv6StaticRoute creates a new entry in the Ipv6StaticRoute list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) NewIpv6StaticRoute(Destination string, Gateway string, Metric uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6StaticRoute == nil {
		t.Ipv6StaticRoute = make(map[CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute_Key]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute)
	}

	key := CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute_Key{
		Destination: Destination,
		Gateway: Gateway,
		Metric: Metric,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6StaticRoute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6StaticRoute", key)
	}

	t.Ipv6StaticRoute[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute{
		Destination: &Destination,
		Gateway: &Gateway,
		Metric: &Metric,
	}

	return t.Ipv6StaticRoute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv4-dynamic-route YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute struct {
	Destination	*string	`path:"destination" module:"ciena-waveserver-interfaces"`
	NextHop	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop	`path:"next-hop" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute) NewNextHop(Index uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Destination == nil {
		return nil, fmt.Errorf("nil value for key Destination")
	}

	return map[string]interface{}{
		"destination": *t.Destination,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv4-dynamic-route/next-hop YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop struct {
	Active	*bool	`path:"active" module:"ciena-waveserver-interfaces"`
	AssociatedInterface	*string	`path:"associated-interface" module:"ciena-waveserver-interfaces"`
	Index	*uint32	`path:"index" module:"ciena-waveserver-interfaces"`
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Static	*bool	`path:"static" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4DynamicRoute_NextHop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv4-static-route YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute struct {
	Destination	*string	`path:"destination" module:"ciena-waveserver-interfaces"`
	NextHop	map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop	`path:"next-hop" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute struct. The keys of the list are populated from the input
// arguments.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute) NewNextHop(Index uint32) (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop, error){

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint32]*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Destination == nil {
		return nil, fmt.Errorf("nil value for key Destination")
	}

	return map[string]interface{}{
		"destination": *t.Destination,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv4-static-route/next-hop YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop struct {
	Active	*bool	`path:"active" module:"ciena-waveserver-interfaces"`
	AssociatedInterface	*string	`path:"associated-interface" module:"ciena-waveserver-interfaces"`
	Index	*uint32	`path:"index" module:"ciena-waveserver-interfaces"`
	IpAddress	*string	`path:"ip-address" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Static	*bool	`path:"static" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv4StaticRoute_NextHop) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv6-dynamic-route YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute struct {
	Active	*bool	`path:"active" module:"ciena-waveserver-interfaces"`
	AssociatedInterface	*string	`path:"associated-interface" module:"ciena-waveserver-interfaces"`
	Destination	*string	`path:"destination" module:"ciena-waveserver-interfaces"`
	Gateway	*string	`path:"gateway" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Static	*bool	`path:"static" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Destination == nil {
		return nil, fmt.Errorf("nil value for key Destination")
	}

	if t.Gateway == nil {
		return nil, fmt.Errorf("nil value for key Gateway")
	}

	if t.Metric == nil {
		return nil, fmt.Errorf("nil value for key Metric")
	}

	return map[string]interface{}{
		"destination": *t.Destination,
		"gateway": *t.Gateway,
		"metric": *t.Metric,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6DynamicRoute) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute represents the /ciena-waveserver-interfaces/waveserver-interfaces/routes/ipv6-static-route YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute struct {
	Active	*bool	`path:"active" module:"ciena-waveserver-interfaces"`
	AssociatedInterface	*string	`path:"associated-interface" module:"ciena-waveserver-interfaces"`
	Destination	*string	`path:"destination" module:"ciena-waveserver-interfaces"`
	Gateway	*string	`path:"gateway" module:"ciena-waveserver-interfaces"`
	Metric	*uint32	`path:"metric" module:"ciena-waveserver-interfaces"`
	Static	*bool	`path:"static" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute struct, which is a YANG list entry.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Destination == nil {
		return nil, fmt.Errorf("nil value for key Destination")
	}

	if t.Gateway == nil {
		return nil, fmt.Errorf("nil value for key Gateway")
	}

	if t.Metric == nil {
		return nil, fmt.Errorf("nil value for key Metric")
	}

	return map[string]interface{}{
		"destination": *t.Destination,
		"gateway": *t.Gateway,
		"metric": *t.Metric,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Routes_Ipv6StaticRoute) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Stacks represents the /ciena-waveserver-interfaces/waveserver-interfaces/stacks YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Stacks struct {
	Ipv6StackState	*CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState	`path:"ipv6-stack-state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Stacks implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Stacks) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Stacks) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Stacks"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Stacks) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState represents the /ciena-waveserver-interfaces/waveserver-interfaces/stacks/ipv6-stack-state YANG schema element.
type CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState struct {
	AcceptRouterAdvertisement	*bool	`path:"accept-router-advertisement" module:"ciena-waveserver-interfaces"`
	MaxSlaacAddresses	*uint32	`path:"max-slaac-addresses" module:"ciena-waveserver-interfaces"`
	Preference	E_CienaWaveserverInterfaces_StackPreference	`path:"preference" module:"ciena-waveserver-interfaces"`
	State	E_CienaWaveserverInterfaces_EnabledDisabledEnum	`path:"state" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *CienaWaveserverInterfaces_WaveserverInterfaces_Stacks_Ipv6StackState) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// Device represents the /device YANG schema element.
type Device struct {
	WaveserverInterfaces	*CienaWaveserverInterfaces_WaveserverInterfaces	`path:"waveserver-interfaces" module:"ciena-waveserver-interfaces"`
}

// IsYANGGoStruct ensures that Device implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Device) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Device) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Device"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Device) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }


// E_CienaWaveserverInterfaces_AclAction is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_AclAction. An additional value named
// CienaWaveserverInterfaces_AclAction_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_AclAction int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_AclAction implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_AclAction can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_AclAction) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_AclAction.
func (E_CienaWaveserverInterfaces_AclAction) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_AclAction.
func (e E_CienaWaveserverInterfaces_AclAction) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_AclAction")
}

const (
	// CienaWaveserverInterfaces_AclAction_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_AclAction
	CienaWaveserverInterfaces_AclAction_UNSET E_CienaWaveserverInterfaces_AclAction = 0
	// CienaWaveserverInterfaces_AclAction_allow corresponds to the value allow of CienaWaveserverInterfaces_AclAction
	CienaWaveserverInterfaces_AclAction_allow E_CienaWaveserverInterfaces_AclAction = 1
	// CienaWaveserverInterfaces_AclAction_drop corresponds to the value drop of CienaWaveserverInterfaces_AclAction
	CienaWaveserverInterfaces_AclAction_drop E_CienaWaveserverInterfaces_AclAction = 2
)


// E_CienaWaveserverInterfaces_EnabledDisabledEnum is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_EnabledDisabledEnum. An additional value named
// CienaWaveserverInterfaces_EnabledDisabledEnum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_EnabledDisabledEnum int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_EnabledDisabledEnum implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_EnabledDisabledEnum can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_EnabledDisabledEnum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_EnabledDisabledEnum.
func (E_CienaWaveserverInterfaces_EnabledDisabledEnum) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_EnabledDisabledEnum.
func (e E_CienaWaveserverInterfaces_EnabledDisabledEnum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_EnabledDisabledEnum")
}

const (
	// CienaWaveserverInterfaces_EnabledDisabledEnum_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_EnabledDisabledEnum
	CienaWaveserverInterfaces_EnabledDisabledEnum_UNSET E_CienaWaveserverInterfaces_EnabledDisabledEnum = 0
	// CienaWaveserverInterfaces_EnabledDisabledEnum_disabled corresponds to the value disabled of CienaWaveserverInterfaces_EnabledDisabledEnum
	CienaWaveserverInterfaces_EnabledDisabledEnum_disabled E_CienaWaveserverInterfaces_EnabledDisabledEnum = 1
	// CienaWaveserverInterfaces_EnabledDisabledEnum_enabled corresponds to the value enabled of CienaWaveserverInterfaces_EnabledDisabledEnum
	CienaWaveserverInterfaces_EnabledDisabledEnum_enabled E_CienaWaveserverInterfaces_EnabledDisabledEnum = 2
)


// E_CienaWaveserverInterfaces_IpAddressType is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_IpAddressType. An additional value named
// CienaWaveserverInterfaces_IpAddressType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_IpAddressType int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_IpAddressType implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_IpAddressType can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_IpAddressType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_IpAddressType.
func (E_CienaWaveserverInterfaces_IpAddressType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_IpAddressType.
func (e E_CienaWaveserverInterfaces_IpAddressType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_IpAddressType")
}

const (
	// CienaWaveserverInterfaces_IpAddressType_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_UNSET E_CienaWaveserverInterfaces_IpAddressType = 0
	// CienaWaveserverInterfaces_IpAddressType_manual corresponds to the value manual of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_manual E_CienaWaveserverInterfaces_IpAddressType = 1
	// CienaWaveserverInterfaces_IpAddressType_dhcp corresponds to the value dhcp of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_dhcp E_CienaWaveserverInterfaces_IpAddressType = 2
	// CienaWaveserverInterfaces_IpAddressType_apipa corresponds to the value apipa of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_apipa E_CienaWaveserverInterfaces_IpAddressType = 3
	// CienaWaveserverInterfaces_IpAddressType_dhcpv6 corresponds to the value dhcpv6 of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_dhcpv6 E_CienaWaveserverInterfaces_IpAddressType = 4
	// CienaWaveserverInterfaces_IpAddressType_slaac corresponds to the value slaac of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_slaac E_CienaWaveserverInterfaces_IpAddressType = 5
	// CienaWaveserverInterfaces_IpAddressType_local corresponds to the value local of CienaWaveserverInterfaces_IpAddressType
	CienaWaveserverInterfaces_IpAddressType_local E_CienaWaveserverInterfaces_IpAddressType = 6
)


// E_CienaWaveserverInterfaces_StackPreference is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_StackPreference. An additional value named
// CienaWaveserverInterfaces_StackPreference_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_StackPreference int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_StackPreference implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_StackPreference can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_StackPreference) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_StackPreference.
func (E_CienaWaveserverInterfaces_StackPreference) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_StackPreference.
func (e E_CienaWaveserverInterfaces_StackPreference) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_StackPreference")
}

const (
	// CienaWaveserverInterfaces_StackPreference_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_StackPreference
	CienaWaveserverInterfaces_StackPreference_UNSET E_CienaWaveserverInterfaces_StackPreference = 0
	// CienaWaveserverInterfaces_StackPreference_ipv4 corresponds to the value ipv4 of CienaWaveserverInterfaces_StackPreference
	CienaWaveserverInterfaces_StackPreference_ipv4 E_CienaWaveserverInterfaces_StackPreference = 1
	// CienaWaveserverInterfaces_StackPreference_ipv6 corresponds to the value ipv6 of CienaWaveserverInterfaces_StackPreference
	CienaWaveserverInterfaces_StackPreference_ipv6 E_CienaWaveserverInterfaces_StackPreference = 2
)


// E_CienaWaveserverInterfaces_UpDownEnum is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_UpDownEnum. An additional value named
// CienaWaveserverInterfaces_UpDownEnum_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_UpDownEnum int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_UpDownEnum implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_UpDownEnum can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_UpDownEnum) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_UpDownEnum.
func (E_CienaWaveserverInterfaces_UpDownEnum) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_UpDownEnum.
func (e E_CienaWaveserverInterfaces_UpDownEnum) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_UpDownEnum")
}

const (
	// CienaWaveserverInterfaces_UpDownEnum_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_UpDownEnum
	CienaWaveserverInterfaces_UpDownEnum_UNSET E_CienaWaveserverInterfaces_UpDownEnum = 0
	// CienaWaveserverInterfaces_UpDownEnum_down corresponds to the value down of CienaWaveserverInterfaces_UpDownEnum
	CienaWaveserverInterfaces_UpDownEnum_down E_CienaWaveserverInterfaces_UpDownEnum = 1
	// CienaWaveserverInterfaces_UpDownEnum_up corresponds to the value up of CienaWaveserverInterfaces_UpDownEnum
	CienaWaveserverInterfaces_UpDownEnum_up E_CienaWaveserverInterfaces_UpDownEnum = 2
)


// E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name. An additional value named
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name.
func (e E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name")
}

const (
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_UNSET E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name = 0
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_peer_1 corresponds to the value peer_1 of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_peer_1 E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name = 1
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_peer_2 corresponds to the value peer_2 of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name_peer_2 E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name = 2
)


// E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState. An additional value named
// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState.
func (e E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState")
}

const (
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_UNSET E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState = 0
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_established corresponds to the value established of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_established E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState = 1
	// CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_active corresponds to the value active of CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState
	CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState_active E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState = 2
)


// E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type. An additional value named
// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type.
func (e E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type")
}

const (
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_UNSET E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 0
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_Unknown corresponds to the value Unknown of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_Unknown E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 1
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_DCN corresponds to the value DCN of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_DCN E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 2
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_ILAN corresponds to the value ILAN of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_ILAN E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 3
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_GCC0 corresponds to the value GCC0 of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_GCC0 E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 4
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_OSC corresponds to the value OSC of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type_OSC E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type = 5
)


// E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex. An additional value named
// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex.
func (e E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex")
}

const (
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_UNSET E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex = 0
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_Unknown corresponds to the value Unknown of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_Unknown E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex = 1
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_full corresponds to the value full of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_full E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex = 2
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_half corresponds to the value half of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex_half E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex = 3
)


// E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed is a derived int64 type which is used to represent
// the enumerated node CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed. An additional value named
// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed int64

// IsYANGGoEnum ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed implements the yang.GoEnum
// interface. This ensures that CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed can be identified as a
// mapped type for a YANG enumeration.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed.
func (E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum; }

// String returns a logging-friendly string for E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed.
func (e E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed) String() string {
	return ygot.EnumLogString(e, int64(e), "E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed")
}

const (
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_UNSET corresponds to the value UNSET of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_UNSET E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 0
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_Unknown corresponds to the value Unknown of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_Unknown E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 1
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_10M corresponds to the value 10M of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_10M E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 11
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_13M corresponds to the value 13M of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_13M E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 14
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_100M corresponds to the value 100M of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_100M E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 101
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_1G corresponds to the value 1G of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_1G E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 1001
	// CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_10G corresponds to the value 10G of CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed
	CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed_10G E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed = 10001
)


// ΛEnum is a map, keyed by the name of the type defined for each enum in the
// generated Go code, which provides a mapping between the constant int64 value
// of each value of the enumeration, and the string that is used to represent it
// in the YANG schema. The map is named ΛEnum in order to avoid clash with any
// valid YANG identifier.
var ΛEnum = map[string]map[int64]ygot.EnumDefinition{
	"E_CienaWaveserverInterfaces_AclAction": {
		1: {Name: "allow"},
		2: {Name: "drop"},
	},
	"E_CienaWaveserverInterfaces_EnabledDisabledEnum": {
		1: {Name: "disabled"},
		2: {Name: "enabled"},
	},
	"E_CienaWaveserverInterfaces_IpAddressType": {
		1: {Name: "manual"},
		2: {Name: "dhcp"},
		3: {Name: "apipa"},
		4: {Name: "dhcpv6"},
		5: {Name: "slaac"},
		6: {Name: "local"},
	},
	"E_CienaWaveserverInterfaces_StackPreference": {
		1: {Name: "ipv4"},
		2: {Name: "ipv6"},
	},
	"E_CienaWaveserverInterfaces_UpDownEnum": {
		1: {Name: "down"},
		2: {Name: "up"},
	},
	"E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name": {
		1: {Name: "peer-1"},
		2: {Name: "peer-2"},
	},
	"E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState": {
		1: {Name: "established"},
		2: {Name: "active"},
	},
	"E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type": {
		1: {Name: "Unknown"},
		2: {Name: "DCN"},
		3: {Name: "ILAN"},
		4: {Name: "GCC0"},
		5: {Name: "OSC"},
	},
	"E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex": {
		1: {Name: "Unknown"},
		2: {Name: "full"},
		3: {Name: "half"},
	},
	"E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed": {
		1: {Name: "Unknown"},
		11: {Name: "10M"},
		14: {Name: "13M"},
		101: {Name: "100M"},
		1001: {Name: "1G"},
		10001: {Name: "10G"},
	},
}


var (
	// ySchema is a byte slice contain a gzip compressed representation of the
	// YANG schema from which the Go code was generated. When uncompressed the
	// contents of the byte slice is a JSON document containing an object, keyed
	// on the name of the generated struct, and containing the JSON marshalled
	// contents of a goyang yang.Entry struct, which defines the schema for the
	// fields within the struct.
	ySchema = []byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0x7d, 0x5f, 0x73, 0xda, 0xc8,
		0xd2, 0xfe, 0xbd, 0x3f, 0x05, 0xa5, 0x2b, 0x38, 0x15, 0x85, 0x3f, 0xc6, 0x24, 0xf6, 0x4d, 0xca,
		0xbb, 0x9b, 0xfd, 0x9d, 0xd4, 0xd9, 0xec, 0xa6, 0x92, 0xdf, 0x79, 0xdf, 0x0b, 0x42, 0xa5, 0x14,
		0x34, 0xd8, 0xaa, 0x80, 0xa4, 0x92, 0x84, 0xff, 0x94, 0xed, 0xef, 0xfe, 0x96, 0x84, 0x10, 0x60,
		0x04, 0xcc, 0xf4, 0xb4, 0x84, 0x80, 0xe7, 0xd4, 0xa9, 0x8d, 0xe3, 0x68, 0x06, 0xd1, 0x33, 0xdd,
		0x4f, 0x77, 0x4f, 0xf7, 0x33, 0x4f, 0x67, 0xb5, 0x5a, 0xad, 0x66, 0xfc, 0x6d, 0x4d, 0x84, 0x71,
		0x55, 0x33, 0x6c, 0x71, 0xe7, 0x0c, 0x85, 0xf1, 0x66, 0xf6, 0xdb, 0xff, 0x38, 0xae, 0x6d, 0x5c,
		0xd5, 0xda, 0xe9, 0x5f, 0x7f, 0xf7, 0xdc, 0x91, 0x73, 0x63, 0x5c, 0xd5, 0x5a, 0xe9, 0x2f, 0xfe,
		0x70, 0x02, 0xe3, 0xaa, 0x36, 0x9b, 0x22, 0xf9, 0xc5, 0xbd, 0x75, 0x27, 0x42, 0x11, 0xdc, 0x89,
		0xc0, 0x74, 0xdc, 0x48, 0x04, 0x23, 0x6b, 0x28, 0xc2, 0x95, 0x47, 0x56, 0x3e, 0x2d, 0xff, 0xf1,
		0x37, 0xab, 0x0f, 0xaf, 0xbe, 0x44, 0xf6, 0xeb, 0xd7, 0x2f, 0x93, 0xfd, 0xc3, 0x97, 0x40, 0x8c,
		0x9c, 0x87, 0xb5, 0x0f, 0x5d, 0xf9, 0x60, 0x67, 0xf4, 0xea, 0x53, 0x92, 0x7f, 0xfd, 0xe6, 0x4d,
		0x83, 0xa1, 0xc8, 0x1d, 0x39, 0x7b, 0x13, 0xf1, 0x78, 0xef, 0x05, 0xf1, 0xcb, 0x18, 0xfe, 0xec,
		0x43, 0xde, 0xe4, 0x3f, 0xf8, 0x6f, 0x2b, 0xbc, 0x0e, 0x6e, 0xa6, 0x13, 0xe1, 0x46, 0xc6, 0x55,
		0x2d, 0x0a, 0xa6, 0x62, 0xc3, 0x83, 0x4b, 0x4f, 0xc5, 0xef, 0xb4, 0xf6, 0xd0, 0xcb, 0xca, 0x6f,
		0x5e, 0x5e, 0x7d, 0xd3, 0xd7, 0xe2, 0xcf, 0xfe, 0xc1, 0x1a, 0x8e, 0x37, 0x7f, 0x8b, 0xb9, 0x0c,
		0xe2, 0x87, 0x36, 0xbc, 0x56, 0xbe, 0xc8, 0x77, 0x8a, 0x5e, 0x66, 0x09, 0xe4, 0x96, 0x42, 0x76,
		0x49, 0x94, 0x97, 0x46, 0x79, 0x89, 0xa4, 0x97, 0x2a, 0x7f, 0xc9, 0x36, 0x2c, 0xdd, 0xce, 0x25,
		0xcc, 0x1e, 0x70, 0xfc, 0xbb, 0xae, 0x69, 0x0d, 0xc7, 0xa6, 0x70, 0xa3, 0xe0, 0x71, 0xb7, 0x20,
		0x32, 0xb1, 0xae, 0x8e, 0xdb, 0xf1, 0xe5, 0xb6, 0x2f, 0xb8, 0xf4, 0xc2, 0xab, 0x6c, 0x00, 0xb5,
		0x8d, 0xa0, 0xba, 0x21, 0xc8, 0x1b, 0x83, 0xbc, 0x41, 0x94, 0x37, 0xca, 0xf6, 0x0d, 0xb3, 0x63,
		0xe3, 0x48, 0x6f, 0xa0, 0xc5, 0x46, 0x72, 0x6d, 0xf1, 0x20, 0x2f, 0xb7, 0x6c, 0x55, 0x92, 0x61,
		0x92, 0x5f, 0x3d, 0xdd, 0x46, 0x2d, 0xc9, 0xc7, 0x65, 0xb7, 0x13, 0x65, 0x5b, 0xd1, 0xb6, 0x17,
		0x75, 0x9b, 0x69, 0x6f, 0x37, 0xed, 0x6d, 0x47, 0xde, 0x7e, 0x72, 0xdb, 0x50, 0x72, 0x3b, 0x66,
		0x6f, 0xf1, 0xff, 0x1f, 0x7d, 0x41, 0x5b, 0xa7, 0xa9, 0xe3, 0x46, 0xe7, 0x1d, 0x95, 0xb5, 0x4a,
		0x77, 0xdd, 0x3b, 0x85, 0x21, 0x5f, 0x2d, 0xf7, 0x26, 0xfe, 0xb4, 0xbe, 0x92, 0x6c, 0xd5, 0xf6,
		0x42, 0xf2, 0x41, 0x9f, 0x1d, 0x57, 0x79, 0x13, 0x11, 0xd5, 0x69, 0x6d, 0xf8, 0xff, 0x58, 0xe3,
		0xa9, 0xd0, 0x18, 0xff, 0x67, 0x60, 0x0d, 0x23, 0xc7, 0x73, 0xff, 0x70, 0x6e, 0x9c, 0x28, 0xf6,
		0xe2, 0x5a, 0xca, 0xf3, 0xbc, 0xbc, 0x21, 0x88, 0xcc, 0x7a, 0xd8, 0xbb, 0xc8, 0xba, 0x9d, 0xcb,
		0xee, 0x65, 0xef, 0x5d, 0xe7, 0xf2, 0x62, 0x8f, 0xb2, 0x3b, 0x2b, 0xe6, 0xe9, 0xc1, 0x19, 0xcf,
		0x7c, 0x12, 0x6b, 0x6b, 0xf8, 0x81, 0xe7, 0x8b, 0x20, 0x72, 0x72, 0x82, 0x80, 0x9d, 0x86, 0x60,
		0x69, 0xac, 0x1a, 0xfc, 0xb4, 0x01, 0x3f, 0xa7, 0x0e, 0x3f, 0xb2, 0x5e, 0xd1, 0x52, 0xc4, 0x14,
		0x6b, 0xab, 0xba, 0xc0, 0x17, 0xc1, 0x54, 0x32, 0x5e, 0x51, 0x58, 0x34, 0x6b, 0xa5, 0xbc, 0x71,
		0x75, 0x36, 0xb0, 0xde, 0x46, 0xd6, 0xdd, 0xd0, 0x6c, 0x1b, 0x9b, 0x6d, 0x83, 0x6b, 0x6f, 0x74,
		0xa2, 0x79, 0x57, 0x5c, 0x69, 0x65, 0xff, 0x2b, 0x2f, 0x3d, 0x60, 0x92, 0x76, 0xf5, 0x8a, 0x29,
		0xee, 0x12, 0xc6, 0x7e, 0x74, 0xa7, 0x93, 0xf8, 0xdd, 0x8b, 0x02, 0x40, 0x05, 0x59, 0x1a, 0xb6,
		0x08, 0x23, 0xc7, 0xb5, 0x62, 0x31, 0x98, 0x8e, 0x6f, 0x5a, 0xb6, 0x1d, 0x88, 0x30, 0xa4, 0xdb,
		0x89, 0x0d, 0xf3, 0xc1, 0x6e, 0xc0, 0x6e, 0x1c, 0x89, 0xdd, 0x70, 0x7c, 0xd3, 0xf3, 0x23, 0x93,
		0x2c, 0xed, 0xcc, 0x74, 0x5c, 0x12, 0xc6, 0xa6, 0xaf, 0xdf, 0x27, 0x2d, 0x0d, 0x6d, 0x8b, 0xad,
		0x67, 0xdd, 0xb4, 0xbe, 0xfe, 0x9a, 0x18, 0xde, 0x6b, 0xcc, 0xf1, 0x97, 0x70, 0x6f, 0xa2, 0x5b,
		0xb2, 0x40, 0xf4, 0x05, 0xc3, 0x12, 0x07, 0x33, 0x07, 0x79, 0xdc, 0x71, 0x72, 0x11, 0xb1, 0x1f,
		0x43, 0x1c, 0xcd, 0x1a, 0x57, 0x97, 0xb5, 0x04, 0x9d, 0x2a, 0xaf, 0xc1, 0xd9, 0x7e, 0x46, 0x0f,
		0x34, 0x0c, 0xc0, 0x17, 0x2b, 0x8a, 0x44, 0xe0, 0x6a, 0x5b, 0x00, 0xa3, 0x5e, 0xef, 0xb7, 0xcc,
		0xcb, 0xc1, 0x73, 0xbf, 0x6d, 0x5e, 0x0e, 0x66, 0x3f, 0xb6, 0x93, 0x3f, 0x66, 0x3f, 0x77, 0xfa,
		0x2d, 0xb3, 0x3b, 0xff, 0xf9, 0xa2, 0xdf, 0x32, 0x2f, 0x06, 0x8d, 0xef, 0xdf, 0xdf, 0x36, 0x9e,
		0xce, 0x5f, 0xd4, 0x07, 0xd6, 0x9b, 0xe9, 0xa7, 0x35, 0x9e, 0xeb, 0xfd, 0xb6, 0xd9, 0x19, 0xcc,
		0xff, 0x72, 0xde, 0x6f, 0x99, 0x9d, 0x41, 0xa3, 0xd1, 0xf8, 0x60, 0xd0, 0xa5, 0x79, 0x56, 0xa2,
		0xfe, 0xf1, 0x20, 0x4a, 0xaf, 0x42, 0x88, 0xc2, 0xb8, 0xa1, 0xae, 0x9e, 0xe3, 0x75, 0xb5, 0xcc,
		0xd1, 0xb5, 0xf9, 0xe7, 0xe0, 0xa9, 0xf5, 0xa6, 0xfb, 0xd2, 0xb8, 0x6a, 0xd4, 0x5f, 0xff, 0xee,
		0xaa, 0xf1, 0xd4, 0x7a, 0x73, 0xf1, 0x52, 0xaf, 0xe7, 0xfc, 0xcb, 0x87, 0xbc, 0x39, 0x1a, 0xcf,
		0xf5, 0x7a, 0x3d, 0xdd, 0x4a, 0x2b, 0xdb, 0xab, 0xdf, 0x6a, 0x0f, 0x3e, 0x24, 0x3f, 0xce, 0xfe,
		0x9b, 0x6d, 0x50, 0xa9, 0x87, 0x1b, 0xab, 0xdb, 0x32, 0xfe, 0xf3, 0xa9, 0xf3, 0xd2, 0x78, 0xae,
		0xc7, 0xbb, 0xb9, 0x9d, 0x6d, 0xd1, 0x76, 0x3c, 0xc9, 0xfb, 0x13, 0xdb, 0xa3, 0x61, 0x14, 0x38,
		0xee, 0xcd, 0xd1, 0x6c, 0xcd, 0xff, 0xba, 0x81, 0x08, 0xbd, 0xf1, 0x9d, 0xb0, 0x4b, 0x5f, 0xc2,
		0xb3, 0x62, 0x3f, 0xa7, 0xf8, 0x18, 0xd9, 0xf7, 0x82, 0x88, 0x27, 0x3a, 0x4e, 0x66, 0x42, 0x5c,
		0x8c, 0xb8, 0xf8, 0x48, 0xe2, 0xe2, 0xa9, 0xe3, 0x46, 0xed, 0x9e, 0x46, 0x40, 0xdc, 0x23, 0x0c,
		0xa5, 0x9d, 0x73, 0x32, 0x40, 0x03, 0x47, 0xbc, 0xc7, 0x14, 0x64, 0x70, 0xc5, 0x77, 0x9c, 0x31,
		0x85, 0x46, 0x3c, 0xc7, 0x12, 0xc7, 0x71, 0x8b, 0xb6, 0x77, 0x71, 0x71, 0x7e, 0x51, 0x21, 0xf1,
		0x9e, 0x10, 0xfa, 0xfa, 0x81, 0x17, 0x79, 0x43, 0x6f, 0x4c, 0x47, 0xdd, 0x6c, 0x06, 0xa0, 0x2d,
		0xd0, 0xf6, 0x48, 0xd0, 0xd6, 0xf1, 0xcd, 0xf9, 0xb6, 0x36, 0xa3, 0x78, 0x36, 0x3a, 0xee, 0x5e,
		0x00, 0x77, 0x81, 0xbb, 0x15, 0xc5, 0xdd, 0xce, 0x05, 0x50, 0x77, 0x2f, 0xa8, 0x1b, 0x26, 0x88,
		0xc0, 0x72, 0x24, 0xbc, 0x3e, 0x15, 0x70, 0x18, 0x38, 0x7c, 0x3c, 0x38, 0x8c, 0xd3, 0x60, 0x9c,
		0x06, 0x17, 0xe0, 0xa5, 0x30, 0x43, 0x2a, 0xb7, 0xd7, 0x52, 0x04, 0xc0, 0x32, 0x78, 0x31, 0xac,
		0xde, 0x4c, 0xd1, 0x4b, 0x80, 0xd3, 0xe0, 0x1c, 0xe7, 0x07, 0xa7, 0xc1, 0x38, 0x0d, 0xc6, 0x69,
		0x30, 0x4e, 0x83, 0x2b, 0xbb, 0x47, 0x71, 0x1a, 0xcc, 0xb5, 0x84, 0x87, 0x1c, 0x19, 0xeb, 0x1d,
		0x04, 0x2f, 0x4f, 0x82, 0x68, 0x18, 0xd1, 0xf0, 0x91, 0x44, 0xc3, 0x38, 0x03, 0xde, 0x77, 0xc2,
		0x14, 0xb9, 0xe8, 0xc2, 0x44, 0x8b, 0x33, 0x60, 0x5e, 0xcc, 0x65, 0x6d, 0x88, 0xbc, 0x76, 0x5d,
		0x2f, 0xb2, 0x94, 0x7b, 0x1c, 0x8d, 0x70, 0x78, 0x2b, 0x26, 0x96, 0x6f, 0x25, 0x79, 0x23, 0xa3,
		0x39, 0x74, 0x84, 0x6b, 0x99, 0xb9, 0xb4, 0x3d, 0xcd, 0xfc, 0xdf, 0x5a, 0xc3, 0x71, 0x73, 0x95,
		0x8b, 0xa4, 0xa9, 0xdc, 0xd8, 0x3b, 0x7b, 0x93, 0x28, 0x98, 0x0e, 0x23, 0x37, 0xb5, 0xa4, 0xbf,
		0xc7, 0x2f, 0xf2, 0xbf, 0xd9, 0x27, 0x7e, 0xca, 0x3e, 0xf0, 0x47, 0xee, 0x2f, 0xaf, 0x87, 0xe3,
		0x1f, 0x9f, 0xfc, 0xbb, 0xee, 0xf5, 0x70, 0xfc, 0x31, 0x7e, 0x87, 0x1f, 0x5f, 0x16, 0xef, 0xc0,
		0xd5, 0x0e, 0xad, 0x45, 0xe3, 0xf1, 0x1f, 0xf1, 0x28, 0xcb, 0xb6, 0x61, 0xfc, 0xe5, 0x84, 0xd1,
		0x75, 0x14, 0x49, 0xf2, 0x7e, 0x7c, 0x76, 0xdc, 0x8f, 0x63, 0x11, 0xa3, 0x6a, 0xac, 0x4f, 0xee,
		0x74, 0x3c, 0x96, 0xe8, 0xdb, 0xfe, 0x6c, 0x3d, 0x2c, 0x0d, 0x52, 0x6c, 0xdc, 0x6e, 0xb7, 0x5a,
		0xb2, 0x1d, 0xdb, 0x04, 0x17, 0x66, 0xd9, 0x6d, 0x99, 0x58, 0x0f, 0xa6, 0x98, 0xbf, 0xa7, 0xc2,
		0x5e, 0xd2, 0x71, 0x58, 0x56, 0x9c, 0x94, 0xf8, 0xab, 0x96, 0xd8, 0x4e, 0xff, 0x4f, 0x60, 0x8b,
		0x40, 0xd8, 0xbf, 0x3d, 0xa6, 0x2b, 0xa9, 0xb5, 0xe5, 0x14, 0x4d, 0x42, 0x11, 0xa6, 0x40, 0x86,
		0xf0, 0x87, 0x55, 0xef, 0xb7, 0x2f, 0xd6, 0xe6, 0x45, 0xda, 0x22, 0xcb, 0x59, 0x4e, 0x86, 0xc6,
		0xd0, 0xd4, 0x03, 0x43, 0x13, 0x18, 0x9a, 0x16, 0x1b, 0x09, 0x0c, 0x4d, 0xa0, 0xc8, 0x28, 0xcd,
		0x23, 0x04, 0x43, 0x93, 0x7e, 0x94, 0x0a, 0x86, 0xa6, 0xbd, 0x89, 0x0c, 0x0c, 0x4d, 0x60, 0x68,
		0x02, 0xfc, 0x80, 0xa1, 0x49, 0x7a, 0x79, 0xc1, 0xd0, 0x54, 0xc8, 0x86, 0x66, 0xdb, 0xd8, 0x6c,
		0x1b, 0x5c, 0x7b, 0xa3, 0x13, 0xcd, 0x3b, 0x18, 0x9a, 0xf8, 0x72, 0x9f, 0x60, 0x68, 0x82, 0xdd,
		0x80, 0xdd, 0x28, 0xc8, 0x6e, 0xa0, 0x26, 0x17, 0x35, 0xb9, 0xbc, 0x71, 0x30, 0x73, 0x90, 0xc7,
		0x1d, 0x27, 0x17, 0x11, 0xfb, 0x31, 0xc4, 0xd1, 0xac, 0x71, 0x75, 0x59, 0x4b, 0x80, 0x9a, 0xdc,
		0x9c, 0x78, 0x1d, 0x35, 0xb9, 0xa8, 0xc9, 0x45, 0x4d, 0x2e, 0x6a, 0x72, 0x2b, 0xbb, 0x47, 0x51,
		0x93, 0xcb, 0xb5, 0x84, 0x60, 0x68, 0x02, 0x43, 0x13, 0xe2, 0x62, 0x54, 0xe7, 0xe6, 0xed, 0x6a,
		0x54, 0xe7, 0xee, 0x37, 0xbe, 0x43, 0x75, 0xee, 0x66, 0xd1, 0xa2, 0x3a, 0x77, 0x6f, 0xe8, 0x0b,
		0x86, 0x26, 0xa0, 0x2d, 0xd0, 0x76, 0x3d, 0x6c, 0x06, 0x43, 0x13, 0x70, 0xf7, 0xe8, 0x71, 0x17,
		0x0c, 0x4d, 0x7b, 0x42, 0x5d, 0x30, 0x34, 0x01, 0x87, 0x81, 0xc3, 0x52, 0x38, 0x8c, 0xd3, 0x60,
		0x9c, 0x06, 0x17, 0xe0, 0xa5, 0x30, 0x43, 0x2a, 0xb7, 0xd7, 0x52, 0x04, 0xc0, 0x32, 0x78, 0x31,
		0xac, 0xde, 0x4c, 0xd1, 0x4b, 0x80, 0xd3, 0xe0, 0x1c, 0xe7, 0x07, 0xa7, 0xc1, 0x38, 0x0d, 0xc6,
		0x69, 0x30, 0x4e, 0x83, 0x2b, 0xbb, 0x47, 0x71, 0x1a, 0xcc, 0xb5, 0x84, 0x60, 0x68, 0xc2, 0x19,
		0x30, 0xa2, 0xe1, 0x23, 0x8a, 0x86, 0x71, 0x06, 0xbc, 0xef, 0x84, 0x29, 0x72, 0xd1, 0x85, 0x89,
		0x16, 0x67, 0xc0, 0xbc, 0x98, 0x7b, 0x54, 0x0c, 0x4d, 0xbd, 0x4a, 0x30, 0x34, 0xf5, 0xc0, 0xd0,
		0x04, 0x86, 0x26, 0x30, 0x34, 0x91, 0x4c, 0x42, 0x11, 0xa6, 0xa0, 0x2c, 0x86, 0xa6, 0x9e, 0x36,
		0x43, 0xd3, 0x99, 0x82, 0x84, 0x65, 0x25, 0xcb, 0x22, 0xd1, 0x2d, 0x22, 0xd4, 0x16, 0x5d, 0xbe,
		0xb4, 0xd6, 0x65, 0x91, 0x23, 0x07, 0xe3, 0xe7, 0x8d, 0xbf, 0xf1, 0xcb, 0x67, 0x96, 0x22, 0x7e,
		0x68, 0x83, 0x0c, 0xb7, 0x73, 0x39, 0xec, 0x0c, 0xd7, 0x64, 0xc2, 0x32, 0xb9, 0xf0, 0x4b, 0xd6,
		0x46, 0x29, 0x87, 0x53, 0xca, 0x56, 0x48, 0x3a, 0x3c, 0x52, 0xdb, 0xad, 0xbb, 0xb8, 0x12, 0x0c,
		0x5f, 0x88, 0x40, 0x9e, 0x78, 0x2c, 0x79, 0x1a, 0x74, 0x63, 0xa7, 0x4e, 0x37, 0x66, 0xd9, 0x77,
		0xb1, 0x7f, 0x15, 0x0a, 0xdb, 0x0c, 0xbc, 0x69, 0x44, 0x21, 0x80, 0x59, 0x9f, 0xa2, 0x60, 0x1e,
		0x98, 0x0e, 0x78, 0x60, 0xb8, 0x52, 0x3a, 0x87, 0xca, 0x03, 0x33, 0xf6, 0x86, 0xd6, 0x38, 0x39,
		0x5d, 0x11, 0x81, 0x70, 0x29, 0xa2, 0x9f, 0x2f, 0xf4, 0xda, 0x4c, 0xc8, 0x63, 0x22, 0x8f, 0x79,
		0x24, 0x79, 0x4c, 0x55, 0x8a, 0xbe, 0xd7, 0x9b, 0xfa, 0xfc, 0x54, 0xd3, 0x98, 0x6d, 0xae, 0xba,
		0xcf, 0x76, 0xf7, 0x5d, 0xf7, 0xfd, 0x79, 0xaf, 0xfb, 0x1e, 0xf9, 0xcc, 0xa2, 0xf2, 0x99, 0x99,
		0x8c, 0xdf, 0x21, 0xa9, 0xc9, 0x96, 0xd4, 0x54, 0xf0, 0x7d, 0x26, 0x22, 0x0a, 0x9c, 0x21, 0x1d,
		0x80, 0xd3, 0xf1, 0x80, 0x5d, 0xc0, 0x2e, 0x60, 0x17, 0xb0, 0x0b, 0xd8, 0x05, 0xec, 0x02, 0x76,
		0x77, 0x8b, 0xcd, 0x15, 0xd1, 0xbd, 0x17, 0xfc, 0xa2, 0xe3, 0xee, 0x7c, 0x02, 0x00, 0x2f, 0x80,
		0xf7, 0x48, 0x80, 0x77, 0x56, 0xd2, 0x68, 0x4e, 0xac, 0x87, 0xb1, 0xa9, 0x85, 0xc0, 0x94, 0x92,
		0x46, 0xdd, 0xbe, 0x0d, 0x54, 0xf0, 0x00, 0x7a, 0xe5, 0x44, 0x7b, 0xde, 0x01, 0xe4, 0xee, 0x07,
		0x72, 0x1f, 0x22, 0xf3, 0xd6, 0xf3, 0x75, 0x30, 0x37, 0x9d, 0x01, 0xa0, 0x0b, 0xd0, 0x05, 0xe8,
		0x02, 0x74, 0x01, 0xba, 0x00, 0x5d, 0x80, 0xee, 0x36, 0xb1, 0xa5, 0x65, 0x57, 0x54, 0xce, 0xa4,
		0x78, 0x34, 0xc0, 0x16, 0x60, 0x7b, 0x84, 0x60, 0xdb, 0xb9, 0xe8, 0x01, 0x6d, 0x81, 0xb6, 0x47,
		0x89, 0xb6, 0x9d, 0x8b, 0x1e, 0xe0, 0x76, 0x1f, 0x70, 0x9b, 0x54, 0xf0, 0x99, 0x6a, 0x97, 0x90,
		0xae, 0x59, 0xa9, 0xe5, 0x49, 0x00, 0xbe, 0x00, 0xdf, 0x23, 0x01, 0xdf, 0xa9, 0xee, 0xc1, 0xee,
		0x3b, 0xb4, 0x85, 0x02, 0x71, 0x2b, 0x8a, 0xb8, 0xba, 0x57, 0xa9, 0x02, 0x78, 0xf5, 0x80, 0xf7,
		0x5e, 0x38, 0x37, 0xb7, 0x1a, 0x54, 0x0c, 0xe9, 0x78, 0xc0, 0x2d, 0xe0, 0xf6, 0x48, 0xe0, 0x16,
		0x65, 0x54, 0xd4, 0xd0, 0x1e, 0x65, 0x54, 0x87, 0x13, 0xe8, 0xa2, 0x8c, 0x8a, 0x1f, 0x76, 0x59,
		0x7b, 0x93, 0xd2, 0x96, 0x7f, 0xf5, 0x98, 0x56, 0x8d, 0x00, 0x60, 0xd9, 0x12, 0x28, 0x13, 0x01,
		0x2c, 0x6f, 0x71, 0xfa, 0x60, 0xa5, 0xb6, 0x75, 0x55, 0x31, 0xee, 0x8d, 0xd9, 0xe2, 0xe7, 0x8d,
		0xdf, 0xf4, 0x85, 0x08, 0x9a, 0xd4, 0x3e, 0xc5, 0x9a, 0x76, 0x8f, 0xf6, 0x6f, 0x37, 0xfe, 0x8f,
		0x2f, 0x42, 0x04, 0x3f, 0xae, 0xb3, 0x57, 0xf8, 0x3a, 0x7b, 0x83, 0x12, 0x49, 0x09, 0xac, 0x69,
		0xe4, 0xb9, 0xde, 0xc4, 0x9b, 0x86, 0x66, 0xf8, 0x18, 0x46, 0x62, 0x42, 0xe8, 0xf4, 0x5c, 0x9b,
		0x42, 0xad, 0xd3, 0xb3, 0x85, 0x1b, 0xff, 0x4f, 0xbd, 0xd3, 0x53, 0xd9, 0x2d, 0xa4, 0x67, 0x5f,
		0x08, 0x59, 0x17, 0xa2, 0xff, 0x47, 0x70, 0x72, 0x75, 0xfc, 0x3d, 0x4d, 0x1f, 0x44, 0x37, 0x9b,
		0xc2, 0xe1, 0x6a, 0x10, 0xdc, 0x38, 0x2d, 0xf7, 0x8d, 0x4b, 0x64, 0xba, 0x59, 0x12, 0x16, 0xd9,
		0x15, 0xe4, 0x36, 0x0d, 0x4a, 0x04, 0xa3, 0x0c, 0x9f, 0xd5, 0x41, 0x68, 0x31, 0x14, 0xe0, 0x03,
		0xf0, 0x29, 0x09, 0x7c, 0xc6, 0xc2, 0x1a, 0x05, 0x62, 0x44, 0x40, 0x9f, 0xb6, 0x0a, 0xfc, 0x7c,
		0x49, 0xdd, 0xdc, 0xb7, 0x6f, 0x9b, 0xb3, 0xff, 0xfb, 0xb7, 0x8f, 0xa1, 0x33, 0xb4, 0xc6, 0x0b,
		0x87, 0xb6, 0xe9, 0xd8, 0xcd, 0xc4, 0x0d, 0x2d, 0x53, 0x5b, 0x7d, 0x82, 0x9a, 0xfa, 0xd0, 0x4f,
		0xe8, 0x67, 0x59, 0xfa, 0x99, 0x5c, 0xe1, 0xa1, 0x7e, 0x2f, 0x0f, 0xa5, 0x18, 0x86, 0x5a, 0x04,
		0x03, 0x27, 0xf1, 0x54, 0x9c, 0xc4, 0x76, 0xef, 0x08, 0x9d, 0x43, 0x35, 0x14, 0x23, 0x71, 0xba,
		0x97, 0x7a, 0x5f, 0x85, 0x51, 0x49, 0xbf, 0x78, 0x22, 0xc2, 0xd0, 0xba, 0x11, 0xa1, 0x19, 0x88,
		0xa1, 0x70, 0xee, 0x84, 0xad, 0x0e, 0xbc, 0xeb, 0x53, 0x14, 0x8c, 0xc3, 0xa0, 0xe3, 0x02, 0x0e,
		0x23, 0x49, 0x03, 0xfc, 0x45, 0x92, 0xe6, 0xc8, 0x92, 0x34, 0x19, 0x92, 0x84, 0x33, 0x8b, 0x44,
		0x05, 0xa2, 0x64, 0x38, 0x40, 0x08, 0x20, 0x04, 0x10, 0x02, 0x08, 0x01, 0x84, 0x00, 0x42, 0x2a,
		0x20, 0x94, 0x1e, 0xb9, 0x2b, 0x62, 0x4f, 0x32, 0x0a, 0xf9, 0x47, 0x40, 0x4e, 0x49, 0x90, 0x23,
		0xdc, 0xe9, 0x44, 0x04, 0xb3, 0xf2, 0x16, 0x42, 0xfa, 0xb1, 0xab, 0x30, 0xe6, 0xa3, 0x3b, 0x4d,
		0x4a, 0x37, 0x5e, 0x4a, 0x54, 0x42, 0xcf, 0x4f, 0xbf, 0x9c, 0x35, 0x36, 0xc3, 0xc8, 0x8a, 0x08,
		0x1a, 0xb9, 0x3e, 0x05, 0x3c, 0x42, 0xa8, 0x27, 0xd4, 0x93, 0x43, 0x3d, 0xe7, 0x99, 0x3e, 0x32,
		0x85, 0xff, 0xeb, 0x09, 0x40, 0xe0, 0x0f, 0xd5, 0x54, 0x52, 0x4d, 0x10, 0xf8, 0x4b, 0x0f, 0x44,
		0x0b, 0x0c, 0x5a, 0x60, 0xa4, 0xd7, 0x19, 0x2d, 0x30, 0xb4, 0x2f, 0x8e, 0x16, 0x18, 0xfe, 0xcc,
		0x08, 0x53, 0x86, 0x64, 0xb3, 0x8c, 0xd1, 0x02, 0xc3, 0x36, 0x3f, 0x08, 0xfc, 0x01, 0xbb, 0x80,
		0x5d, 0xc0, 0x2e, 0x60, 0x17, 0xb0, 0x0b, 0xd8, 0xad, 0x24, 0xec, 0x82, 0xc0, 0x1f, 0xc0, 0x0b,
		0xe0, 0x5d, 0x5d, 0x67, 0x70, 0x09, 0x57, 0x07, 0x1f, 0xc0, 0xb5, 0x54, 0x98, 0x68, 0xc1, 0x25,
		0xbc, 0x2f, 0xc8, 0x05, 0x81, 0x3f, 0x40, 0x17, 0xa0, 0x0b, 0xd0, 0x05, 0xe8, 0x02, 0x74, 0x01,
		0xba, 0xa5, 0x80, 0x2e, 0x08, 0xfc, 0x01, 0xb6, 0x00, 0x5b, 0x10, 0xf8, 0x03, 0x6d, 0x4f, 0x09,
		0x6d, 0x41, 0xe0, 0xbf, 0x27, 0xb8, 0x05, 0x81, 0x3f, 0xc0, 0x17, 0xe0, 0x9b, 0xbf, 0xce, 0x20,
		0xf0, 0x07, 0xe2, 0x1e, 0x2d, 0xe2, 0x82, 0xc0, 0x7f, 0xbf, 0xc0, 0x0b, 0x02, 0x7f, 0xc0, 0x2d,
		0xe0, 0x16, 0x65, 0x54, 0x0c, 0x90, 0x80, 0x32, 0xaa, 0x03, 0x0a, 0x74, 0x51, 0x46, 0xc5, 0x0f,
		0xbb, 0x20, 0xf0, 0x07, 0x81, 0xff, 0x3a, 0x81, 0x3f, 0xad, 0x4b, 0xb1, 0xc6, 0x47, 0xdf, 0xff,
		0x35, 0x7d, 0x81, 0xf2, 0xc9, 0xfb, 0xa7, 0xbe, 0x19, 0x39, 0x14, 0x22, 0x84, 0xf9, 0x40, 0x34,
		0x5b, 0x97, 0xe4, 0x26, 0xa2, 0xd9, 0x7a, 0xf9, 0x88, 0xa3, 0xdd, 0x03, 0x1b, 0x6b, 0x0d, 0x44,
		0x3c, 0xfb, 0x14, 0xd9, 0x51, 0xb2, 0xb1, 0x72, 0x41, 0xcf, 0x99, 0xc6, 0x8a, 0xcf, 0x1d, 0x2b,
		0x09, 0xae, 0x1d, 0xe3, 0xe3, 0x43, 0x22, 0xc1, 0xdd, 0x3a, 0xfa, 0x74, 0xa6, 0x6a, 0xa5, 0xdd,
		0xe1, 0xc3, 0xd5, 0x34, 0x14, 0x81, 0x79, 0x1f, 0x38, 0xf2, 0xac, 0x22, 0x54, 0x2b, 0xbd, 0x62,
		0x9d, 0xa7, 0xbe, 0x6d, 0x45, 0x12, 0x4c, 0xec, 0xdb, 0xc5, 0xbc, 0x83, 0x5a, 0x57, 0xcd, 0x0b,
		0x25, 0x79, 0x9f, 0x24, 0xaf, 0x53, 0xcd, 0xdb, 0xdc, 0xb5, 0x97, 0x14, 0xbd, 0x4b, 0x3e, 0xaf,
		0x52, 0x62, 0xc3, 0xf0, 0x78, 0x8f, 0xdb, 0xb7, 0xc9, 0xe6, 0x2d, 0xb2, 0x45, 0x72, 0x86, 0x1f,
		0x78, 0xbe, 0x08, 0x22, 0x47, 0x82, 0xf3, 0x63, 0x51, 0x51, 0xb3, 0x18, 0xb3, 0x4b, 0xbf, 0xa5,
		0xb2, 0x11, 0xd2, 0xb9, 0x44, 0x15, 0xe7, 0x4f, 0xcd, 0xe9, 0x53, 0x75, 0xf6, 0xc8, 0x4e, 0x1e,
		0x8f, 0xd9, 0x90, 0x71, 0xea, 0xf4, 0x2c, 0xb3, 0x2c, 0x1d, 0x87, 0xb1, 0x74, 0x27, 0x9a, 0x6a,
		0x3f, 0xd2, 0xe2, 0x56, 0xb0, 0xf5, 0x39, 0x10, 0x6d, 0x20, 0xda, 0x28, 0x29, 0xda, 0x48, 0x6e,
		0x7e, 0x50, 0x96, 0x1d, 0x42, 0x0d, 0x84, 0x1a, 0xfc, 0x22, 0xeb, 0xb4, 0x70, 0xf1, 0x43, 0xe5,
		0x2f, 0x7e, 0x68, 0xa6, 0x1f, 0xd6, 0x78, 0xae, 0xf7, 0xdb, 0x66, 0x67, 0x30, 0xff, 0xcb, 0x79,
		0xbf, 0x65, 0x76, 0x06, 0x8d, 0x8a, 0x5e, 0x0c, 0x81, 0xdb, 0x3b, 0x01, 0xd3, 0xe0, 0xe4, 0xde,
		0x31, 0x04, 0x9c, 0xdc, 0xc0, 0xe7, 0x6d, 0x22, 0x03, 0x27, 0x37, 0x0f, 0x18, 0xdd, 0x7a, 0x63,
		0xdb, 0x1b, 0x8d, 0x88, 0x47, 0x52, 0x2b, 0xa3, 0x01, 0x41, 0x80, 0xa0, 0x12, 0x21, 0x88, 0x74,
		0x1e, 0xd5, 0x03, 0x04, 0xe5, 0xdb, 0xd3, 0x73, 0x40, 0x90, 0xaa, 0xc8, 0x7a, 0x17, 0x17, 0xe7,
		0x40, 0x1f, 0x2d, 0xf4, 0xf9, 0x25, 0x84, 0x6f, 0x5a, 0x63, 0xe7, 0x4e, 0x10, 0x01, 0xe8, 0xf5,
		0x04, 0xc0, 0x20, 0x60, 0x10, 0x30, 0xe8, 0x40, 0x31, 0xa8, 0x0d, 0x0c, 0x02, 0x06, 0xf1, 0x62,
		0xd0, 0x01, 0x1e, 0x64, 0xcb, 0x9e, 0xe9, 0xd6, 0x78, 0x8e, 0xb3, 0x17, 0x1f, 0x57, 0xc0, 0xa1,
		0x76, 0x30, 0x75, 0x63, 0x58, 0x96, 0xbd, 0xcc, 0x62, 0xd1, 0xb4, 0xba, 0x3a, 0x8e, 0xf9, 0x70,
		0xbb, 0x83, 0xc3, 0x6d, 0x36, 0x54, 0x2e, 0xe9, 0x70, 0xfb, 0xc6, 0x8a, 0xc4, 0xbd, 0xf5, 0xa8,
		0xee, 0x20, 0xce, 0x07, 0xc2, 0x31, 0x84, 0x63, 0x58, 0x92, 0x63, 0x48, 0x26, 0xe1, 0xc2, 0x49,
		0xf6, 0x4e, 0x7f, 0x07, 0x99, 0x72, 0xf5, 0xcc, 0x4e, 0x07, 0xfe, 0xa1, 0x4e, 0x8e, 0x22, 0xf3,
		0xcf, 0xd4, 0xc1, 0x67, 0x31, 0x14, 0xf0, 0x03, 0xf8, 0xd9, 0x03, 0xfc, 0xa0, 0x67, 0x03, 0xf0,
		0x83, 0x9e, 0x8d, 0x83, 0x86, 0x1f, 0x5f, 0xcd, 0x64, 0x2f, 0xd5, 0x86, 0xab, 0xc4, 0x8b, 0x00,
		0x1e, 0x00, 0x0f, 0xe2, 0x1e, 0x00, 0x0f, 0xe2, 0x1e, 0x00, 0xcf, 0x3c, 0x77, 0x4b, 0x60, 0x1f,
		0xd4, 0x60, 0x1d, 0x04, 0x04, 0x01, 0x82, 0xb4, 0x21, 0x08, 0xa5, 0xa9, 0x00, 0x1e, 0x94, 0xa6,
		0x1e, 0x09, 0x00, 0x45, 0x2a, 0x66, 0x20, 0x33, 0x01, 0xc9, 0x28, 0x40, 0x0e, 0x20, 0x07, 0x51,
		0x0f, 0xc0, 0x07, 0x51, 0x0f, 0x40, 0x47, 0x0d, 0x74, 0xaa, 0xce, 0xce, 0x05, 0xe8, 0x01, 0xf4,
		0xe0, 0xa4, 0x07, 0xd0, 0x53, 0x41, 0xe8, 0xc1, 0x49, 0x0f, 0xf5, 0x09, 0x49, 0x76, 0x2e, 0xf9,
		0xa4, 0x1a, 0x88, 0xa6, 0xf2, 0x9e, 0x67, 0xa9, 0xcf, 0x55, 0x2a, 0x4d, 0xad, 0xb1, 0xd4, 0xe8,
		0x7e, 0x9d, 0x7d, 0xa4, 0x0c, 0x55, 0x29, 0xad, 0x4c, 0x37, 0x8c, 0xac, 0x48, 0xc8, 0x57, 0xe7,
		0xce, 0x1e, 0x07, 0xe3, 0x14, 0x18, 0xa7, 0x26, 0x8e, 0x6b, 0xca, 0x6d, 0x9e, 0xb5, 0xb5, 0x59,
		0x1e, 0x0c, 0x9f, 0x19, 0x3e, 0x73, 0x49, 0x3e, 0xb3, 0x70, 0xad, 0x9f, 0x63, 0x61, 0x9b, 0xb6,
		0x13, 0xce, 0x7e, 0x10, 0xee, 0x74, 0x42, 0x71, 0x9d, 0xbb, 0x0a, 0x63, 0x3e, 0xc6, 0x9f, 0x71,
		0x55, 0x7b, 0x7a, 0x29, 0x31, 0x90, 0xf5, 0x7c, 0x11, 0x24, 0xd8, 0x68, 0x8d, 0xa9, 0x2a, 0xba,
		0x3e, 0x05, 0xc8, 0xe0, 0xa0, 0xa8, 0x50, 0xd4, 0xb2, 0xdc, 0xfe, 0xbd, 0xf8, 0xb7, 0xb2, 0x8a,
		0xae, 0xef, 0xd6, 0x7e, 0x8b, 0x76, 0x32, 0xee, 0x6e, 0x71, 0x67, 0xcf, 0x14, 0x24, 0x2a, 0x2b,
		0x49, 0x16, 0x09, 0x1a, 0x5b, 0x1d, 0x6d, 0x3d, 0x99, 0xe5, 0x4b, 0x6b, 0x5d, 0x16, 0x39, 0x72,
		0x30, 0xc6, 0xde, 0x8d, 0x33, 0xb4, 0xc6, 0xe6, 0xee, 0x7a, 0xf6, 0x4c, 0x07, 0xd7, 0x87, 0x6c,
		0x90, 0xef, 0x76, 0x67, 0x7f, 0xa7, 0x27, 0x26, 0x63, 0xd0, 0xe5, 0x0c, 0xb8, 0xac, 0xc1, 0x56,
		0x36, 0xd0, 0xca, 0x06, 0x59, 0xda, 0x00, 0xab, 0xed, 0xe4, 0x5d, 0xce, 0xb9, 0xe1, 0xd8, 0xf2,
		0x81, 0x9c, 0x63, 0x23, 0x8a, 0x43, 0x14, 0x17, 0x86, 0xde, 0xd0, 0xb1, 0x22, 0x61, 0x9b, 0xfe,
		0xed, 0x63, 0x28, 0x69, 0x23, 0x36, 0xc7, 0x75, 0x5b, 0xa7, 0x83, 0x03, 0x09, 0x07, 0xb2, 0x24,
		0x07, 0x72, 0x2c, 0xac, 0x51, 0x20, 0x46, 0x14, 0x97, 0xf1, 0x9d, 0x1a, 0x51, 0x6a, 0xe2, 0x2c,
		0xbc, 0x7d, 0xdb, 0x9c, 0xfd, 0x7f, 0x7d, 0xd7, 0x37, 0x1d, 0xbb, 0x99, 0x60, 0x3e, 0xab, 0x64,
		0x4e, 0xe3, 0x46, 0x2b, 0x96, 0x58, 0x38, 0xf6, 0xca, 0x94, 0x0d, 0xd9, 0x76, 0x57, 0x0e, 0xe6,
		0x0a, 0xe6, 0x8a, 0xd5, 0x5c, 0xfd, 0xf4, 0xbc, 0xb1, 0xb0, 0x5c, 0x8a, 0xb9, 0x6a, 0x97, 0xd9,
		0x0d, 0x3b, 0x22, 0x56, 0x84, 0xcf, 0x07, 0x42, 0xa5, 0xa0, 0x52, 0x25, 0xa9, 0x14, 0xaa, 0xc1,
		0x89, 0xea, 0xb4, 0x36, 0x1c, 0x55, 0x11, 0x64, 0x91, 0xa1, 0x1a, 0x9c, 0x91, 0x86, 0xc1, 0xb5,
		0xc6, 0x44, 0x16, 0x86, 0x78, 0x24, 0xa0, 0x07, 0xd0, 0x03, 0x6f, 0x6e, 0xf9, 0x33, 0xd3, 0x4c,
		0xb4, 0xa2, 0x42, 0x49, 0xdc, 0x12, 0xa8, 0xad, 0x4c, 0x38, 0xb3, 0x87, 0x32, 0xa1, 0xce, 0x15,
		0x1e, 0x5d, 0x05, 0x3d, 0x3a, 0xd4, 0xb9, 0x52, 0x9f, 0xa8, 0xdc, 0x81, 0xf7, 0xda, 0x01, 0x67,
		0x73, 0xe7, 0x91, 0x58, 0x4d, 0xfb, 0x1c, 0xf7, 0xaf, 0xd9, 0x87, 0x66, 0xbf, 0xf9, 0xf1, 0xc9,
		0x2e, 0xa2, 0xa8, 0xd3, 0x71, 0x7f, 0x5a, 0xae, 0x6d, 0x3a, 0x23, 0xd3, 0x15, 0xce, 0xcd, 0xed,
		0x4f, 0x2f, 0x48, 0x8a, 0x78, 0xa6, 0x0a, 0x34, 0xac, 0x9b, 0xa7, 0x00, 0x23, 0xeb, 0xa9, 0x1f,
		0x1b, 0x26, 0x97, 0x35, 0x66, 0xdb, 0x22, 0xa9, 0x86, 0x0e, 0x4c, 0x89, 0xc3, 0xe7, 0xf5, 0x75,
		0xda, 0x30, 0x11, 0x1c, 0x4c, 0x38, 0x98, 0xa5, 0x3a, 0x98, 0x70, 0x2c, 0xe1, 0x58, 0xee, 0x37,
		0x55, 0xd8, 0x82, 0x63, 0xa9, 0x95, 0x22, 0x8c, 0x91, 0x84, 0xa1, 0xee, 0x79, 0xc3, 0x3c, 0x00,
		0x24, 0x00, 0x52, 0x49, 0x80, 0x34, 0xf5, 0x4d, 0xdb, 0xbb, 0x77, 0x8f, 0xb6, 0x39, 0xc1, 0xf1,
		0xef, 0x7a, 0x5c, 0xce, 0x63, 0x0f, 0xce, 0x23, 0x74, 0x15, 0xce, 0x23, 0x9c, 0x47, 0x38, 0x8f,
		0x70, 0x1e, 0x35, 0x21, 0x89, 0xc7, 0x79, 0xec, 0xc1, 0x79, 0x04, 0x20, 0xc1, 0x79, 0x2c, 0x4a,
		0x53, 0x27, 0x22, 0x0a, 0x9c, 0xa1, 0xba, 0x66, 0xa6, 0xe3, 0xa0, 0x89, 0xd0, 0xc4, 0xb2, 0x34,
		0x11, 0x05, 0x88, 0x70, 0x0c, 0x51, 0x80, 0x88, 0x63, 0xeb, 0xd5, 0xe7, 0x8b, 0x38, 0xb6, 0x26,
		0x9e, 0xd4, 0xd6, 0x0a, 0x38, 0xcd, 0x4e, 0x5e, 0xe5, 0xd3, 0xe8, 0xef, 0xf4, 0x45, 0xbe, 0xcd,
		0xde, 0xa3, 0x80, 0x13, 0x6e, 0xa9, 0xea, 0x35, 0x95, 0xaa, 0x35, 0x49, 0x95, 0x43, 0xbb, 0x6b,
		0x11, 0xe0, 0xad, 0xa7, 0x83, 0xd2, 0x20, 0x4d, 0xe8, 0x0f, 0x54, 0xe9, 0x0b, 0x5c, 0xee, 0x07,
		0x94, 0x6a, 0xfb, 0xa3, 0x6d, 0xfd, 0xa5, 0x5b, 0x82, 0xa5, 0x15, 0x40, 0xfa, 0x66, 0x61, 0x74,
		0x7d, 0x1f, 0xac, 0x1a, 0x28, 0x95, 0x6f, 0xd0, 0x4e, 0xc6, 0x14, 0x03, 0xa8, 0x36, 0x02, 0xa8,
		0x53, 0x0f, 0xa0, 0x64, 0x37, 0x65, 0x36, 0x80, 0x42, 0x2c, 0xb7, 0xb6, 0xc6, 0xea, 0x04, 0x73,
		0x9a, 0x9e, 0xb7, 0xf2, 0x16, 0xd6, 0xd9, 0xca, 0x7a, 0x5b, 0x5a, 0x77, 0x6b, 0xb3, 0x6d, 0x71,
		0xb6, 0xad, 0xae, 0xbd, 0xe5, 0x89, 0xa1, 0x8a, 0xe2, 0x4a, 0x2b, 0xe7, 0x12, 0xd6, 0xd6, 0x59,
		0x97, 0x17, 0x4b, 0x27, 0xdd, 0x47, 0x4c, 0xfb, 0xa9, 0x8b, 0x56, 0x41, 0xac, 0x86, 0xe5, 0x3b,
		0xbe, 0x65, 0x3a, 0xbe, 0x69, 0xd9, 0x76, 0x20, 0xc2, 0x50, 0xc3, 0x62, 0xbc, 0x9e, 0xa9, 0x64,
		0xb3, 0xd1, 0x81, 0xd9, 0x80, 0xd9, 0x28, 0xc8, 0x6c, 0x24, 0x35, 0x4d, 0x64, 0x59, 0x53, 0x8e,
		0xac, 0xb3, 0xb1, 0xc4, 0xa3, 0x6b, 0x7a, 0xa6, 0x92, 0x25, 0x63, 0xc9, 0x94, 0x86, 0xe3, 0xca,
		0x60, 0x72, 0x66, 0xe3, 0x34, 0x32, 0x9a, 0x2c, 0x99, 0xcd, 0xa2, 0x44, 0xdb, 0xa9, 0x92, 0x6c,
		0xcf, 0xca, 0x19, 0x35, 0x20, 0x28, 0xe4, 0x17, 0x2b, 0x8a, 0x44, 0xe0, 0x92, 0x35, 0xd2, 0xa8,
		0xd7, 0xfb, 0x2d, 0xf3, 0x72, 0xf0, 0xdc, 0x6f, 0x9b, 0x97, 0x83, 0xd9, 0x8f, 0xed, 0xe4, 0x8f,
		0xd9, 0xcf, 0x9d, 0x7e, 0xcb, 0xec, 0xce, 0x7f, 0xbe, 0xe8, 0xb7, 0xcc, 0x8b, 0x41, 0xe3, 0xfb,
		0xf7, 0xb7, 0x8d, 0xa7, 0xf3, 0x17, 0xf5, 0x81, 0xcd, 0xf4, 0xc3, 0x1a, 0xcf, 0xf5, 0x7e, 0xdb,
		0xec, 0x0c, 0xe6, 0x7f, 0x39, 0xef, 0xb7, 0xcc, 0xce, 0xa0, 0xd1, 0x50, 0x37, 0xd5, 0x83, 0x0a,
		0x38, 0x2d, 0x3f, 0xad, 0xe1, 0xaf, 0xa9, 0x6f, 0xde, 0x58, 0x91, 0xb8, 0xb7, 0x1e, 0xe9, 0x2e,
		0xcb, 0xab, 0x79, 0x10, 0xe7, 0xc0, 0x61, 0x39, 0x26, 0x87, 0x85, 0xe6, 0x88, 0xc3, 0x63, 0x81,
		0xc7, 0x72, 0x18, 0x1e, 0x0b, 0xb5, 0x95, 0x18, 0x1e, 0x4b, 0x85, 0x3d, 0x96, 0xc3, 0xf4, 0x48,
		0xec, 0xdb, 0x21, 0x83, 0x3f, 0xb2, 0x32, 0x0b, 0xd2, 0x27, 0xf0, 0x46, 0xe0, 0x8d, 0xc0, 0x1b,
		0x81, 0x37, 0x02, 0x6f, 0x04, 0xde, 0x08, 0xbc, 0x11, 0x55, 0x6f, 0x84, 0xe3, 0x4c, 0xe7, 0xf5,
		0x44, 0xf0, 0x49, 0xe0, 0x93, 0x1c, 0x93, 0x4f, 0x82, 0x23, 0x1d, 0xb8, 0x24, 0x47, 0xec, 0x92,
		0xe0, 0x48, 0xe7, 0x08, 0x5d, 0x92, 0xe3, 0x3c, 0xd2, 0xf1, 0x7c, 0x11, 0xe8, 0x27, 0x50, 0x56,
		0x66, 0x81, 0xb3, 0x02, 0x67, 0x05, 0x09, 0x14, 0x78, 0x2b, 0xf0, 0x56, 0x90, 0x40, 0x81, 0xb7,
		0x82, 0x04, 0x8a, 0xaa, 0x37, 0xc2, 0x91, 0x40, 0x79, 0x3d, 0x11, 0x7c, 0x12, 0xf8, 0x24, 0x48,
		0xa0, 0xc0, 0x25, 0x81, 0x4b, 0x82, 0x04, 0x0a, 0x5c, 0x12, 0x24, 0x50, 0xf8, 0x5c, 0x96, 0x69,
		0xc8, 0x91, 0x40, 0x59, 0x99, 0x05, 0xf5, 0xb0, 0x70, 0x56, 0x90, 0x40, 0x81, 0xb7, 0x02, 0x6f,
		0x05, 0x09, 0x14, 0x78, 0x2b, 0x48, 0xa0, 0xa8, 0x7a, 0x23, 0x1c, 0x09, 0x94, 0xd7, 0x13, 0xc1,
		0x27, 0x81, 0x4f, 0x82, 0x04, 0x0a, 0x5c, 0x12, 0xb8, 0x24, 0x48, 0xa0, 0xc0, 0x25, 0x41, 0x02,
		0x85, 0xe3, 0x49, 0x59, 0x26, 0x26, 0x45, 0xa6, 0xca, 0x6c, 0x5c, 0x01, 0x8c, 0x95, 0x0b, 0x36,
		0xba, 0xa6, 0x02, 0xab, 0x58, 0x8d, 0x9f, 0xaf, 0xf2, 0x4b, 0xf6, 0x22, 0x3f, 0x3e, 0xc5, 0x2f,
		0x52, 0x32, 0xe7, 0x3c, 0x8d, 0x61, 0x1e, 0x24, 0x6c, 0x65, 0x79, 0x85, 0x27, 0x4b, 0xc2, 0x96,
		0xe6, 0x50, 0xcd, 0x61, 0xb2, 0x27, 0xa6, 0x81, 0xba, 0xd9, 0x58, 0x59, 0xed, 0xfc, 0xe9, 0x68,
		0xc1, 0x50, 0x1b, 0xc1, 0x10, 0x82, 0x21, 0xde, 0x60, 0x48, 0x55, 0x3d, 0x96, 0x6c, 0x38, 0x39,
		0x45, 0x90, 0x63, 0xd9, 0x35, 0x32, 0xbc, 0x0c, 0xce, 0x2f, 0x59, 0x51, 0x38, 0x14, 0x86, 0x47,
		0x71, 0xb8, 0x14, 0x88, 0x5d, 0x91, 0xd8, 0x15, 0x8a, 0x4d, 0xb1, 0x34, 0xa3, 0x0b, 0xe2, 0x4e,
		0x21, 0x67, 0x1f, 0x72, 0xfd, 0x21, 0x4d, 0xbd, 0xd1, 0x4d, 0x47, 0xb0, 0x45, 0x41, 0xd9, 0x44,
		0x71, 0x44, 0x62, 0x99, 0xa3, 0x6b, 0xf3, 0xcf, 0xab, 0xef, 0xdf, 0xdf, 0x0e, 0xfe, 0x45, 0x5f,
		0xd6, 0x41, 0x49, 0x41, 0x23, 0xe5, 0x7e, 0x04, 0xfa, 0x7d, 0x4b, 0x1b, 0x77, 0x03, 0xf5, 0xea,
		0xa5, 0xc2, 0x4c, 0x69, 0x07, 0xa6, 0x14, 0xa6, 0xf4, 0x40, 0x4c, 0x29, 0x17, 0xb9, 0xec, 0x9a,
		0x4d, 0xed, 0x6a, 0xcc, 0x41, 0x23, 0x9b, 0x2d, 0xd7, 0x90, 0x85, 0x9a, 0xee, 0x7a, 0x76, 0x99,
		0xe4, 0x6c, 0x1e, 0x78, 0x7f, 0x30, 0x59, 0x30, 0x59, 0x8a, 0x31, 0x93, 0x19, 0xc5, 0x93, 0x9e,
		0x9a, 0xb1, 0x2a, 0x34, 0x2a, 0x26, 0xe6, 0x8b, 0x17, 0x66, 0xb1, 0xe8, 0xbc, 0x71, 0xaf, 0xc9,
		0x91, 0x57, 0xaa, 0x15, 0x9d, 0x55, 0xee, 0xfd, 0xf8, 0x7f, 0xb3, 0xd7, 0xfc, 0x7d, 0xe5, 0x2d,
		0xd1, 0xb5, 0xca, 0x90, 0xd3, 0x43, 0x87, 0x08, 0x72, 0x7a, 0xdc, 0x39, 0xbd, 0xb9, 0x1a, 0x9b,
		0x52, 0x57, 0x8c, 0xed, 0xde, 0x2e, 0xab, 0xf3, 0xc1, 0xbb, 0x83, 0x77, 0x07, 0xef, 0x4e, 0x2e,
		0x1e, 0x4a, 0x2e, 0xd7, 0x37, 0x27, 0xd6, 0xc3, 0xd8, 0x6c, 0xf7, 0xf6, 0x9d, 0xdd, 0xd3, 0x2c,
		0x3a, 0x9a, 0xff, 0x4f, 0x6f, 0xd7, 0xd6, 0xb8, 0x8a, 0x90, 0x98, 0x0c, 0xcb, 0xda, 0x74, 0x4c,
		0x45, 0x49, 0xd9, 0x7c, 0x8c, 0x05, 0x34, 0x9a, 0x1b, 0x7b, 0x75, 0x09, 0x18, 0x8a, 0x95, 0x8a,
		0x5e, 0x02, 0xdd, 0x7a, 0xea, 0x42, 0xd7, 0xe0, 0x6c, 0x3f, 0xa3, 0xab, 0x9c, 0x0f, 0xc7, 0x61,
		0x22, 0x1c, 0x0e, 0x38, 0x1c, 0xfb, 0x4d, 0x27, 0xe1, 0x30, 0xf1, 0x40, 0x8d, 0xe7, 0x44, 0x44,
		0x81, 0x33, 0xd4, 0x37, 0x9c, 0xe9, 0x3c, 0x30, 0x9a, 0x30, 0x9a, 0x30, 0x9a, 0x52, 0xfb, 0x64,
		0xea, 0xb8, 0xd1, 0x79, 0x87, 0xc1, 0x5c, 0xbe, 0xd3, 0x98, 0xe2, 0xab, 0xe5, 0xde, 0x08, 0xc4,
		0x66, 0x88, 0xcd, 0x0e, 0x24, 0x36, 0xeb, 0x76, 0x2e, 0xbb, 0x97, 0xbd, 0x77, 0x9d, 0xcb, 0x0b,
		0xc4, 0x68, 0x87, 0xe4, 0x66, 0xe0, 0xa8, 0x1f, 0x6e, 0x06, 0xdc, 0x8c, 0xfd, 0xc4, 0x66, 0x38,
		0xea, 0x2f, 0x6a, 0xb9, 0xe2, 0xed, 0xaf, 0x95, 0x35, 0x32, 0xfe, 0x72, 0xc2, 0xe8, 0x3a, 0x8a,
		0x88, 0x47, 0x6e, 0x9f, 0x1d, 0xf7, 0xe3, 0x58, 0xc4, 0xbb, 0x3b, 0x46, 0x2e, 0x77, 0x3a, 0x1e,
		0x13, 0x4c, 0xf3, 0x67, 0xeb, 0x41, 0x7f, 0x92, 0x7f, 0x02, 0x5b, 0x04, 0xc2, 0xfe, 0xed, 0x31,
		0x9d, 0xe2, 0xd4, 0x0b, 0x2c, 0x34, 0xce, 0xf6, 0x6b, 0xc5, 0xd7, 0x55, 0xfc, 0xe3, 0x8b, 0x20,
		0xad, 0xad, 0x30, 0x40, 0xbb, 0xb9, 0x66, 0xdf, 0x50, 0x54, 0x51, 0x16, 0xec, 0xa3, 0xa8, 0x62,
		0xc7, 0x40, 0xdb, 0xb2, 0xcd, 0x91, 0xe5, 0x8c, 0xa7, 0x01, 0x83, 0xf3, 0xbc, 0x3c, 0x19, 0x3c,
		0x68, 0x78, 0xd0, 0xf0, 0xa0, 0xa5, 0xf6, 0xc9, 0x4f, 0xcf, 0x1b, 0x0b, 0xcb, 0xe5, 0xf0, 0x9c,
		0xdb, 0x38, 0x46, 0x85, 0xa1, 0x81, 0xa1, 0x81, 0xa1, 0xd9, 0xa0, 0x35, 0x77, 0x3d, 0x53, 0x7b,
		0x6d, 0xaa, 0x75, 0x8a, 0x5a, 0xaf, 0x5f, 0x3d, 0x2f, 0x4e, 0x52, 0x07, 0x4f, 0xad, 0x37, 0xdd,
		0x97, 0xc6, 0x55, 0xa3, 0xfe, 0xfa, 0x77, 0x57, 0x8d, 0xa7, 0xd6, 0x9b, 0x8b, 0x97, 0x7a, 0x3d,
		0xe7, 0x5f, 0x3e, 0xe4, 0xcd, 0xd1, 0x78, 0xae, 0xd7, 0xeb, 0x29, 0x35, 0xcd, 0x0a, 0x5d, 0x4d,
		0xbf, 0xd5, 0x1e, 0x7c, 0x48, 0x7e, 0x9c, 0xfd, 0x37, 0x23, 0xbc, 0x91, 0x7a, 0xb8, 0xd1, 0xa8,
		0x2f, 0xf3, 0xdc, 0xc4, 0x7f, 0x3e, 0x75, 0x5e, 0x1a, 0xcf, 0xf5, 0x76, 0xbf, 0x65, 0xb6, 0x33,
		0xce, 0x9b, 0x76, 0x3c, 0xc9, 0xfb, 0xf8, 0x71, 0x03, 0xf9, 0x5a, 0xe4, 0x6b, 0x01, 0x02, 0x00,
		0x01, 0xe4, 0x6b, 0x91, 0xaf, 0x45, 0xbe, 0xf6, 0x90, 0xf3, 0xb5, 0x5a, 0x51, 0x4b, 0x09, 0x29,
		0xdb, 0x4f, 0xfe, 0x75, 0xfa, 0x7a, 0xa0, 0xfa, 0x65, 0x4b, 0xda, 0x82, 0xdd, 0x0a, 0x49, 0x5b,
		0xe6, 0xa4, 0x2d, 0x32, 0x29, 0x70, 0xa2, 0xe1, 0x44, 0x23, 0x93, 0x82, 0x4c, 0xca, 0xb1, 0x65,
		0x52, 0x10, 0x9c, 0x28, 0x05, 0x27, 0x9a, 0xd8, 0x47, 0x2d, 0x8e, 0xe6, 0x30, 0xf4, 0xcb, 0x46,
		0x7e, 0x62, 0x3d, 0x98, 0x62, 0xfe, 0xad, 0x34, 0x4c, 0x01, 0xa7, 0x99, 0x5f, 0x31, 0xf1, 0x1d,
		0xa3, 0xc2, 0xa9, 0x44, 0x84, 0x9a, 0xab, 0xa1, 0xa6, 0x5e, 0xbc, 0x53, 0x42, 0xa8, 0xf9, 0xdf,
		0xb0, 0x8c, 0x50, 0xf3, 0x34, 0x28, 0xda, 0x7b, 0x55, 0xa1, 0x68, 0xef, 0xb1, 0x51, 0xb4, 0x9f,
		0x69, 0x2c, 0x98, 0xea, 0x42, 0x15, 0xbb, 0x40, 0x12, 0x6b, 0x53, 0xd8, 0x9a, 0x6c, 0x5f, 0x8e,
		0xcd, 0x42, 0xde, 0x22, 0x60, 0x43, 0x8e, 0x0c, 0x74, 0x89, 0x26, 0x62, 0x37, 0xd1, 0xa7, 0x64,
		0x7a, 0x45, 0x3a, 0x4a, 0x54, 0x89, 0x06, 0xd5, 0xa2, 0x3e, 0x55, 0xd0, 0x27, 0x47, 0x71, 0x64,
		0x18, 0x57, 0x8e, 0xca, 0xf4, 0x54, 0x4d, 0x36, 0x7d, 0x61, 0x58, 0xf6, 0xc4, 0x71, 0x15, 0x99,
		0x64, 0xb3, 0xb5, 0x59, 0x1e, 0xac, 0x76, 0xbd, 0x42, 0x0b, 0xd7, 0x2b, 0x9c, 0xfa, 0xf5, 0x0a,
		0xca, 0x01, 0x3f, 0x1b, 0xe7, 0x2a, 0xe5, 0x6c, 0x4c, 0xf1, 0x2c, 0x8c, 0xe7, 0xb6, 0x13, 0x3a,
		0xd9, 0xb3, 0x36, 0xb9, 0x33, 0x59, 0x51, 0x3b, 0x50, 0x54, 0x28, 0xea, 0xfc, 0x74, 0xc7, 0x37,
		0x6d, 0xef, 0xde, 0x3d, 0x4c, 0xfd, 0x3c, 0x74, 0x57, 0x57, 0x56, 0xdb, 0x99, 0xbd, 0xdc, 0x6f,
		0xc9, 0xc7, 0x52, 0x1d, 0xdc, 0x33, 0x05, 0x61, 0xcf, 0x73, 0x66, 0x5b, 0x18, 0x02, 0x8d, 0x8f,
		0x0f, 0x49, 0x2e, 0x6a, 0x73, 0xf6, 0x75, 0x87, 0xbb, 0xbc, 0x64, 0x03, 0xdc, 0xe1, 0xc3, 0x55,
		0x12, 0xbe, 0xdf, 0x07, 0xce, 0x6e, 0xd7, 0x59, 0x55, 0xf7, 0x57, 0x74, 0x7d, 0xea, 0xdb, 0x5b,
		0x85, 0x98, 0x2f, 0xa6, 0x0d, 0x77, 0xd0, 0xc9, 0x65, 0x06, 0x95, 0x32, 0x80, 0x4a, 0x65, 0x08,
		0x72, 0x39, 0xa0, 0x4d, 0x6b, 0x2c, 0xa9, 0x48, 0x05, 0x28, 0x90, 0xb1, 0x35, 0xd8, 0x62, 0x54,
		0x99, 0xfc, 0x75, 0x5e, 0x5f, 0xe3, 0x1c, 0x11, 0x19, 0xfe, 0xed, 0x63, 0xf8, 0xea, 0xb5, 0x37,
		0x89, 0x29, 0xb3, 0xca, 0x39, 0x63, 0x36, 0x29, 0xd8, 0xd6, 0xf8, 0x6f, 0xa7, 0x73, 0x2e, 0x83,
		0xf1, 0x72, 0x98, 0x2e, 0x8b, 0xe1, 0xca, 0x98, 0xad, 0xa7, 0xa7, 0xdb, 0x30, 0x59, 0xcd, 0x94,
		0xed, 0x8a, 0xd7, 0x0c, 0xc7, 0x96, 0x8f, 0xed, 0x1d, 0x1b, 0x81, 0xfd, 0xc9, 0x07, 0xf6, 0xce,
		0xc8, 0x71, 0x6d, 0xf1, 0x40, 0xb8, 0x2c, 0x31, 0x1d, 0x88, 0x38, 0x01, 0x71, 0x42, 0x59, 0x71,
		0x82, 0x2a, 0x1b, 0x12, 0x81, 0xfd, 0x88, 0xc8, 0x76, 0x44, 0x3b, 0x4b, 0xd5, 0xa8, 0xd3, 0xd2,
		0x2b, 0xd8, 0xd1, 0x64, 0x2b, 0xe2, 0x60, 0xc4, 0x79, 0xa1, 0x9d, 0x1c, 0xef, 0x5d, 0x64, 0xba,
		0xec, 0x42, 0x2c, 0xb2, 0x2b, 0xe8, 0xc0, 0x6d, 0x50, 0x62, 0xd2, 0x4a, 0x89, 0x00, 0x3e, 0x33,
		0x01, 0x0a, 0x34, 0xef, 0xc8, 0x21, 0x03, 0x72, 0xb4, 0x21, 0x87, 0x4c, 0x93, 0x4e, 0xa9, 0x0b,
		0xa3, 0xd2, 0xa0, 0x03, 0x7c, 0x4e, 0x05, 0x7c, 0xa8, 0xb4, 0xe3, 0x00, 0x9d, 0x99, 0x18, 0x22,
		0x15, 0x43, 0x90, 0x19, 0x01, 0x85, 0x1e, 0x2b, 0xc4, 0x39, 0x00, 0x1d, 0x6d, 0xd0, 0x11, 0xee,
		0x74, 0x22, 0x94, 0xef, 0xdb, 0xc2, 0x71, 0x88, 0x7a, 0x36, 0x77, 0x3d, 0xc7, 0xd9, 0xdc, 0x99,
		0x15, 0xd3, 0xcf, 0xec, 0x7e, 0x49, 0x3f, 0x75, 0x71, 0x1a, 0xf2, 0xc9, 0x2e, 0xa2, 0xd6, 0x47,
		0xca, 0xc5, 0x56, 0x71, 0xad, 0x25, 0xad, 0x1b, 0x12, 0x82, 0xd5, 0x4b, 0x08, 0x4a, 0x5b, 0xa3,
		0x4c, 0xce, 0x63, 0x61, 0x8d, 0x02, 0x21, 0x25, 0xec, 0xb9, 0xe5, 0x91, 0xc8, 0xb3, 0x18, 0x5f,
		0x52, 0x6d, 0x7d, 0xfb, 0xb6, 0xe9, 0xd8, 0xcd, 0x64, 0xd3, 0x15, 0xb0, 0xf5, 0x97, 0x0a, 0xf8,
		0xa4, 0x15, 0x40, 0xba, 0xe8, 0x0f, 0x79, 0xf1, 0xe3, 0xcf, 0x8b, 0x8b, 0xe8, 0x56, 0x04, 0xae,
		0x88, 0xd4, 0xbd, 0xc5, 0x6c, 0xa4, 0x9a, 0xc7, 0xd8, 0x86, 0xc7, 0x78, 0xea, 0x1e, 0xa3, 0x6a,
		0x33, 0xa9, 0x61, 0x4d, 0x23, 0xcf, 0x74, 0xc5, 0x8d, 0x17, 0x39, 0xb4, 0x7e, 0x86, 0x45, 0x89,
		0xe6, 0xeb, 0x99, 0x68, 0x1d, 0xd6, 0x2d, 0xd0, 0x62, 0x16, 0xbd, 0xd9, 0xd9, 0x36, 0xbd, 0xf6,
		0xe6, 0x27, 0x26, 0x06, 0x14, 0x57, 0x9a, 0xdc, 0xf0, 0xc9, 0xc0, 0xcd, 0x47, 0xe4, 0xe4, 0x2b,
		0x86, 0x4c, 0xc1, 0x9e, 0xfa, 0x63, 0xf1, 0x40, 0x57, 0xf1, 0x74, 0x3c, 0x14, 0x1b, 0x8a, 0x7d,
		0x24, 0x8a, 0x4d, 0xcb, 0x93, 0xe8, 0xe4, 0x4b, 0x88, 0x79, 0x93, 0x62, 0x0d, 0xc3, 0x68, 0xec,
		0xdd, 0x9b, 0x43, 0xcf, 0x8d, 0x02, 0x6f, 0x4c, 0x37, 0x0f, 0x2b, 0xb3, 0xc0, 0x48, 0xc0, 0x48,
		0x00, 0xfd, 0xab, 0x84, 0xfe, 0x13, 0x6b, 0xa8, 0x4f, 0xa3, 0xb4, 0x3c, 0x09, 0x54, 0x1c, 0x2a,
		0x7e, 0x24, 0x2a, 0x1e, 0x6f, 0xeb, 0xd9, 0x41, 0xbd, 0x8e, 0x96, 0x13, 0x08, 0x5c, 0x74, 0xef,
		0x2d, 0xd7, 0xa0, 0x9e, 0xe0, 0xb8, 0x0b, 0x8f, 0xe9, 0x02, 0xb6, 0xc5, 0xe9, 0xb4, 0xe6, 0x3c,
		0x8c, 0xf7, 0xac, 0x69, 0xdc, 0x75, 0xc7, 0x72, 0xc7, 0x1d, 0xb7, 0x68, 0x3b, 0xad, 0x0a, 0xc9,
		0xb6, 0x24, 0x22, 0x91, 0x41, 0x05, 0x60, 0x37, 0xf4, 0x85, 0xb0, 0xe9, 0x80, 0x3b, 0x1b, 0x0e,
		0xa8, 0x05, 0xd4, 0x22, 0xe4, 0xae, 0x7c, 0xc8, 0x7d, 0x1c, 0x6c, 0x33, 0x39, 0x25, 0x0d, 0x4b,
		0x74, 0x33, 0x8a, 0x87, 0x53, 0xb5, 0x02, 0x6a, 0x1d, 0x96, 0x38, 0x67, 0x3e, 0xce, 0xdf, 0x06,
		0xd5, 0x27, 0xe5, 0x13, 0xcf, 0x6c, 0x5b, 0x19, 0x30, 0xcf, 0xe0, 0x20, 0xbe, 0x58, 0x65, 0x03,
		0xf3, 0x0c, 0x8e, 0xe3, 0xd9, 0xbd, 0x28, 0x30, 0xcf, 0x80, 0x79, 0x86, 0x2b, 0x3c, 0x82, 0xa2,
		0x9e, 0x80, 0xa2, 0x82, 0x79, 0x66, 0x9f, 0xce, 0x6e, 0x39, 0xd4, 0x33, 0xeb, 0x7e, 0x2e, 0xb8,
		0x67, 0x6a, 0xe0, 0x9e, 0x59, 0x79, 0xf8, 0x30, 0xb8, 0x67, 0xa4, 0x19, 0x59, 0x0a, 0x50, 0x1a,
		0x1d, 0xf6, 0x99, 0xc0, 0x9b, 0x46, 0x5b, 0x0a, 0xb1, 0x33, 0x6b, 0x9c, 0x3e, 0x07, 0x96, 0x99,
		0xca, 0xb3, 0xcc, 0xf8, 0x77, 0x5d, 0xd3, 0x7e, 0x74, 0xad, 0x89, 0x33, 0x34, 0x93, 0x55, 0x53,
		0x60, 0x9d, 0x59, 0x1f, 0xcb, 0x1c, 0xe4, 0x77, 0x10, 0xe4, 0x1f, 0x5a, 0x90, 0x6f, 0x8b, 0x30,
		0x72, 0x5c, 0xb5, 0x74, 0xe9, 0xa2, 0xb0, 0x71, 0x69, 0x30, 0x82, 0x7c, 0xc4, 0x0e, 0x25, 0xc5,
		0x0e, 0x89, 0x21, 0x53, 0x96, 0x1d, 0x78, 0x01, 0x36, 0x0e, 0x07, 0x2f, 0x00, 0x59, 0x64, 0x9d,
		0xd6, 0x11, 0xf2, 0x02, 0x28, 0x28, 0x08, 0xf5, 0x02, 0x25, 0x23, 0xbd, 0x7c, 0xe8, 0xb9, 0xdf,
		0x36, 0x2f, 0xd3, 0x4b, 0x8a, 0xda, 0xc9, 0x1f, 0xb3, 0x9f, 0x97, 0x2f, 0x2f, 0x4a, 0x2f, 0x34,
		0xca, 0x2e, 0x38, 0x52, 0x1e, 0xb8, 0x7c, 0xd3, 0x51, 0xdb, 0xec, 0x64, 0xb7, 0x1b, 0x9d, 0xf7,
		0x5b, 0x66, 0x67, 0xa0, 0x72, 0xb7, 0x51, 0xa9, 0x3c, 0x3d, 0xe2, 0x21, 0x32, 0x6f, 0x3d, 0x9f,
		0xc0, 0xd5, 0x33, 0x1f, 0x59, 0x70, 0x23, 0x1c, 0x40, 0xf9, 0xd8, 0x40, 0x59, 0xbd, 0x11, 0x6e,
		0x18, 0x39, 0x77, 0x42, 0xa3, 0xfd, 0x6d, 0x36, 0x1e, 0x85, 0x3a, 0xbc, 0x1b, 0x9a, 0x6d, 0x63,
		0xb3, 0x6d, 0x70, 0xed, 0x8d, 0x4e, 0x44, 0x3d, 0x94, 0xbd, 0x93, 0x84, 0x61, 0x58, 0x61, 0xe8,
		0x0d, 0x1d, 0x2b, 0x12, 0xb6, 0x04, 0x75, 0xf1, 0x6e, 0x35, 0xcf, 0x9b, 0x0d, 0x4a, 0x0f, 0xa5,
		0x3f, 0x12, 0xa5, 0x27, 0xb3, 0xd5, 0xe9, 0x44, 0xa7, 0xba, 0x51, 0x2a, 0x3d, 0x5a, 0x65, 0x89,
		0x5a, 0x99, 0x42, 0x31, 0xae, 0x28, 0x96, 0x33, 0x32, 0xd3, 0x88, 0x6a, 0x59, 0xa2, 0xdb, 0xa2,
		0x44, 0x4b, 0x65, 0xc1, 0x2b, 0x44, 0xb6, 0x27, 0x54, 0x0c, 0xaf, 0xc6, 0x14, 0xbe, 0x8e, 0x42,
		0x0a, 0x7c, 0xe1, 0x6c, 0x70, 0x8b, 0xab, 0xfb, 0x01, 0xb7, 0x45, 0xc1, 0xad, 0x32, 0x1f, 0xf9,
		0xeb, 0x5d, 0xfd, 0x8e, 0x30, 0x94, 0xc6, 0x4f, 0x7e, 0xa4, 0x20, 0x8b, 0x8e, 0xb3, 0x93, 0x10,
		0xed, 0x29, 0x61, 0xac, 0xaf, 0xdf, 0xe6, 0x4d, 0xbf, 0x1d, 0x1e, 0x68, 0x0b, 0xb4, 0xad, 0x2a,
		0xda, 0x26, 0xe7, 0xad, 0x1a, 0x17, 0xa2, 0x23, 0xb4, 0x45, 0x68, 0x8b, 0xd0, 0xb6, 0x8a, 0xb0,
		0x4b, 0x50, 0x48, 0xea, 0x81, 0x6f, 0x36, 0x41, 0x99, 0x07, 0xbf, 0xc6, 0x41, 0x7a, 0x22, 0x13,
		0x11, 0x05, 0xce, 0x50, 0x83, 0x6c, 0x66, 0x36, 0x5e, 0x11, 0x27, 0xfe, 0x10, 0x23, 0x6b, 0x3a,
		0x4e, 0x40, 0xac, 0x05, 0xef, 0x05, 0xde, 0x0b, 0x72, 0x05, 0xc8, 0x15, 0xc0, 0x6b, 0xa9, 0xb8,
		0xd7, 0xd2, 0x69, 0x77, 0xdf, 0x75, 0xdf, 0x9f, 0xf7, 0xba, 0xef, 0x91, 0x34, 0xd8, 0x07, 0x54,
		0x87, 0x91, 0x15, 0xe9, 0x40, 0x75, 0x3a, 0x1e, 0x27, 0xe1, 0x80, 0xdb, 0x23, 0x81, 0xdb, 0x2a,
		0x97, 0xbf, 0xb0, 0x96, 0xca, 0xa5, 0x0d, 0x86, 0x4a, 0x77, 0xf1, 0x4a, 0x75, 0xdb, 0xe5, 0x61,
		0xfa, 0x52, 0x43, 0x1d, 0xd1, 0xd2, 0xb4, 0x55, 0x8d, 0x8c, 0x86, 0xea, 0x2d, 0xab, 0xdd, 0xc4,
		0x71, 0x4d, 0x31, 0x7f, 0x7b, 0xc2, 0xa6, 0xe0, 0x50, 0xbc, 0x15, 0xa5, 0x6b, 0x1b, 0x15, 0xc0,
		0x8d, 0xd5, 0x1e, 0xc9, 0x43, 0x5b, 0x52, 0xeb, 0x01, 0x4b, 0xba, 0xf6, 0x42, 0x52, 0x9d, 0xac,
		0x54, 0x63, 0xb3, 0x37, 0x52, 0xab, 0x59, 0x67, 0x68, 0x73, 0xbd, 0x77, 0xb0, 0xa9, 0x58, 0x64,
		0x5e, 0xd3, 0xee, 0x8c, 0xfd, 0x9a, 0xbc, 0xca, 0x8f, 0x4f, 0xfe, 0x5d, 0xf7, 0x8f, 0xd9, 0x9b,
		0x24, 0xbf, 0xf9, 0xf1, 0xb7, 0x78, 0x88, 0xfe, 0xed, 0xf9, 0xd5, 0xa0, 0xb2, 0x4a, 0x51, 0x41,
		0xbe, 0x33, 0x4e, 0x0d, 0x13, 0x94, 0x3a, 0xb1, 0x37, 0x58, 0x1b, 0xc9, 0x41, 0x4a, 0xfb, 0xb9,
		0x72, 0xa4, 0x07, 0x1b, 0xf7, 0x6d, 0xe1, 0xac, 0x07, 0x1b, 0xb6, 0x69, 0x11, 0xc4, 0x5e, 0xc9,
		0xb7, 0x9b, 0x85, 0x10, 0xa4, 0x66, 0xe0, 0x95, 0xa1, 0x20, 0xfc, 0x42, 0x2f, 0x30, 0x7a, 0x81,
		0xd1, 0x76, 0xb4, 0x8f, 0x58, 0x0a, 0xbd, 0xc0, 0x6c, 0x49, 0x5c, 0xf4, 0x02, 0xef, 0x4d, 0x64,
		0xe8, 0x05, 0x46, 0x2f, 0x30, 0x25, 0xe0, 0x40, 0x2f, 0x30, 0x40, 0xb9, 0x82, 0xa0, 0x8c, 0x5e,
		0x60, 0xae, 0x0d, 0xac, 0xb7, 0x91, 0x39, 0xd2, 0x77, 0x35, 0x1c, 0x86, 0xe0, 0x30, 0x84, 0x9c,
		0xda, 0x44, 0x2f, 0x30, 0x94, 0x1e, 0x4a, 0x2f, 0xbb, 0xce, 0xe8, 0x05, 0xa6, 0xff, 0x0f, 0xa5,
		0x47, 0xec, 0xd1, 0x6d, 0x51, 0xa2, 0x45, 0x2f, 0xf0, 0x7e, 0xc0, 0x18, 0xbd, 0xc0, 0x80, 0x5b,
		0xc0, 0x2d, 0xea, 0x7b, 0x2b, 0x84, 0x04, 0x00, 0xd9, 0x53, 0x10, 0x2d, 0x7a, 0x81, 0xd5, 0xf0,
		0x07, 0xbd, 0xc0, 0x40, 0x5b, 0xf4, 0x02, 0x23, 0xb4, 0x45, 0x68, 0x8b, 0xd0, 0x16, 0xbd, 0xc0,
		0xb9, 0x13, 0xa0, 0x17, 0x78, 0x97, 0x84, 0xd0, 0x0b, 0x0c, 0xef, 0x05, 0xde, 0x0b, 0x72, 0x05,
		0xf0, 0x5a, 0xe0, 0xb5, 0xec, 0x10, 0x2d, 0x7a, 0x81, 0xf7, 0x0b, 0xd5, 0xe8, 0x05, 0x06, 0xdc,
		0x02, 0x6e, 0xd1, 0x0b, 0x8c, 0x5e, 0xe0, 0x4d, 0x6a, 0x87, 0x5e, 0xe0, 0x0d, 0xbe, 0x04, 0x7a,
		0x81, 0xd1, 0x0b, 0x7c, 0x58, 0xbd, 0xc0, 0xcb, 0xad, 0x83, 0x7b, 0x6d, 0x05, 0xfe, 0x96, 0xbc,
		0x08, 0x3a, 0x81, 0x29, 0x9d, 0xc0, 0x8a, 0xad, 0x04, 0xd2, 0x91, 0x33, 0xc5, 0xb8, 0x30, 0x18,
		0x15, 0x2d, 0x63, 0xb2, 0x62, 0x44, 0xce, 0x3b, 0x46, 0x89, 0xcd, 0x1d, 0xc7, 0xd3, 0x69, 0xad,
		0xd0, 0x50, 0x5c, 0x94, 0x11, 0x28, 0xa8, 0xcf, 0xba, 0xa7, 0x71, 0xeb, 0x72, 0x0f, 0xb7, 0x2e,
		0xeb, 0x45, 0x60, 0x47, 0xd7, 0x69, 0xad, 0xd8, 0x29, 0x43, 0xeb, 0x90, 0x21, 0xf7, 0x57, 0x77,
		0xd0, 0xca, 0xc5, 0xe5, 0x9e, 0x1e, 0x7c, 0x7f, 0xb5, 0x7a, 0x08, 0xaf, 0x18, 0xba, 0xf3, 0x40,
		0xa8, 0x56, 0x87, 0x0a, 0x47, 0x67, 0x0a, 0x94, 0x0d, 0xca, 0xa6, 0xad, 0x6c, 0xe4, 0xce, 0x11,
		0xf0, 0x19, 0x6c, 0x1c, 0x0e, 0x3e, 0x03, 0xb2, 0xc8, 0xa8, 0x65, 0x30, 0x95, 0xe6, 0x33, 0x28,
		0x11, 0x94, 0xc0, 0xa7, 0x03, 0x08, 0x3a, 0x34, 0x08, 0x4a, 0xc2, 0xd5, 0x72, 0xf8, 0x74, 0x34,
		0xe8, 0x42, 0xae, 0x9e, 0xfb, 0x2d, 0xf3, 0xd2, 0x32, 0x47, 0xd7, 0xe6, 0x9f, 0x83, 0xa7, 0xd6,
		0x9b, 0xee, 0x4b, 0xe3, 0xaa, 0x51, 0x7f, 0xfd, 0xbb, 0xab, 0xc6, 0x53, 0xeb, 0xcd, 0xc5, 0x4b,
		0xbd, 0x9e, 0xf3, 0x2f, 0x1f, 0xf2, 0xe6, 0x68, 0x3c, 0xd7, 0xeb, 0xf5, 0xb4, 0x5e, 0x6c, 0xa5,
		0x86, 0xac, 0xdf, 0x6a, 0x0f, 0x3e, 0x24, 0x3f, 0xce, 0xfe, 0x9b, 0x55, 0xa1, 0x49, 0x3d, 0xdc,
		0x68, 0xd4, 0x97, 0x59, 0x47, 0xe2, 0x3f, 0x9f, 0x3a, 0x2f, 0x8d, 0xe7, 0x7a, 0xbb, 0xdf, 0x32,
		0xdb, 0x19, 0x03, 0x49, 0x3b, 0x9e, 0xe4, 0x7d, 0xfc, 0x78, 0x35, 0x39, 0x48, 0x6e, 0xac, 0x48,
		0xdc, 0x5b, 0x8f, 0xea, 0xa6, 0x6c, 0x3e, 0x10, 0x66, 0x0c, 0x66, 0xac, 0x4c, 0x33, 0xa6, 0x5e,
		0xa6, 0x5e, 0xae, 0x1d, 0x5b, 0xd8, 0x9f, 0xab, 0xef, 0xdf, 0xdf, 0x0e, 0xfe, 0x55, 0x4d, 0xb5,
		0x57, 0xac, 0x40, 0xa5, 0x55, 0x9e, 0x42, 0xe9, 0xa1, 0xf4, 0xda, 0x4a, 0xaf, 0x5c, 0xdd, 0x49,
		0xa8, 0xea, 0x24, 0x56, 0x73, 0x22, 0x68, 0x3e, 0x95, 0xa0, 0x59, 0xb7, 0x0a, 0x13, 0xc1, 0xf3,
		0x4c, 0x0c, 0x8a, 0xd5, 0x94, 0xb4, 0x2a, 0x4a, 0x64, 0x6d, 0x01, 0x3b, 0xda, 0xb0, 0x53, 0x85,
		0x23, 0x12, 0xe6, 0x4a, 0x95, 0x5a, 0x1a, 0xb2, 0xd5, 0xa4, 0x9c, 0x38, 0x50, 0xd8, 0xe7, 0x1a,
		0x30, 0xbe, 0xc2, 0x8a, 0xde, 0xde, 0x28, 0xec, 0x7b, 0x25, 0x50, 0xd8, 0xf7, 0xe8, 0x14, 0xf6,
		0x3d, 0x50, 0xd8, 0xd7, 0x50, 0x58, 0xb1, 0xf4, 0x20, 0x0a, 0x2b, 0xe0, 0x35, 0xc0, 0x6b, 0x60,
		0x74, 0xc3, 0x51, 0x58, 0x01, 0x65, 0x43, 0x61, 0x05, 0x0a, 0x2b, 0x90, 0x23, 0x42, 0x61, 0x45,
		0x65, 0x72, 0x43, 0x28, 0xac, 0x00, 0x04, 0x1d, 0x1a, 0x04, 0xa1, 0xb0, 0x02, 0x85, 0x15, 0x1b,
		0xc4, 0x8e, 0xc2, 0x0a, 0x98, 0xb1, 0x83, 0x32, 0x63, 0x28, 0xac, 0xe0, 0x50, 0x7b, 0x14, 0x56,
		0x40, 0xe9, 0x0f, 0x43, 0xe9, 0x51, 0x58, 0x81, 0xa0, 0x19, 0x85, 0x15, 0x28, 0xac, 0x40, 0x61,
		0x05, 0x60, 0xa7, 0x44, 0xd8, 0x41, 0x61, 0x05, 0x18, 0x41, 0xc0, 0x08, 0x72, 0xd8, 0x85, 0x2b,
		0x7b, 0x62, 0x04, 0xe9, 0x71, 0x30, 0x82, 0x9c, 0x29, 0x48, 0x5b, 0x56, 0xca, 0x5c, 0xd2, 0xdd,
		0x22, 0x4b, 0x0e, 0x19, 0xe6, 0xcb, 0x6c, 0x5d, 0x22, 0x39, 0xd2, 0x88, 0x1d, 0x85, 0xe1, 0xaf,
		0xcd, 0xc6, 0x64, 0xd9, 0xa1, 0x88, 0x9f, 0xdb, 0x20, 0xcf, 0xed, 0xc5, 0x3a, 0x3b, 0xe3, 0x54,
		0x19, 0x07, 0x41, 0xce, 0x21, 0x90, 0x35, 0x5d, 0xca, 0x80, 0xaf, 0x6c, 0x9c, 0xa4, 0x01, 0x5d,
		0x6d, 0xe7, 0xee, 0x2a, 0xae, 0xc9, 0x0a, 0xad, 0x86, 0xbf, 0x12, 0x75, 0x26, 0x94, 0x68, 0x65,
		0x23, 0x51, 0xa1, 0x85, 0x0a, 0xad, 0xa1, 0xf0, 0xa3, 0x19, 0x20, 0x04, 0xa6, 0x65, 0xdf, 0x89,
		0x20, 0x72, 0x42, 0x91, 0xbe, 0xa9, 0x72, 0xd9, 0xd6, 0xe6, 0xc9, 0x90, 0x1f, 0x43, 0xa0, 0x72,
		0x42, 0x81, 0x8a, 0x4c, 0xc2, 0xd9, 0x7a, 0x30, 0xc3, 0xb1, 0x65, 0x0d, 0xe7, 0x09, 0x7c, 0x41,
		0x70, 0xf9, 0xf3, 0x26, 0x81, 0xaa, 0x41, 0xd5, 0x90, 0x8a, 0x3e, 0xd0, 0x54, 0x74, 0x1b, 0xa9,
		0x68, 0x55, 0x91, 0x9d, 0x77, 0x90, 0x82, 0xd6, 0x01, 0xa2, 0xd8, 0xf6, 0x89, 0x40, 0xb8, 0x94,
		0x52, 0xe2, 0xa5, 0xb1, 0x80, 0x1d, 0xc0, 0x4e, 0x49, 0xb0, 0x33, 0x8b, 0x61, 0x95, 0xf7, 0xde,
		0x8a, 0xab, 0xd7, 0x55, 0x18, 0xf3, 0xd1, 0x9d, 0x4e, 0xe2, 0x37, 0x7d, 0x29, 0xf9, 0x60, 0x48,
		0xd0, 0xce, 0x85, 0xa0, 0x8b, 0xd0, 0xc5, 0xd2, 0x74, 0x51, 0xb8, 0xd6, 0xcf, 0xb1, 0xb0, 0x4d,
		0xdb, 0x09, 0x67, 0x3f, 0x88, 0x58, 0x59, 0x0e, 0x4d, 0x21, 0x0f, 0x2b, 0xa5, 0x3f, 0xcb, 0xd5,
		0x36, 0x15, 0xf3, 0x79, 0xfa, 0xd9, 0xe8, 0x6f, 0xc9, 0xe7, 0xce, 0x33, 0xfa, 0xc3, 0x5f, 0xdf,
		0x92, 0x4f, 0x3d, 0xae, 0x84, 0xfe, 0xd6, 0x3c, 0x38, 0x97, 0x08, 0xa5, 0x13, 0xfa, 0x67, 0x5b,
		0x64, 0xb3, 0x4b, 0x26, 0xda, 0xb2, 0x30, 0x72, 0x8f, 0x13, 0xe8, 0x5f, 0x7e, 0xf5, 0x5b, 0x2f,
		0xbe, 0xdb, 0xec, 0xa7, 0xf4, 0xdb, 0x6d, 0xfa, 0x56, 0x86, 0x13, 0xfe, 0x69, 0xfd, 0x12, 0x5f,
		0x3d, 0x6f, 0xdd, 0xd0, 0xbe, 0xfe, 0xa6, 0xc6, 0xf2, 0x3f, 0xad, 0xbc, 0xf0, 0x1f, 0xe2, 0xce,
		0x19, 0xa6, 0x5b, 0xf6, 0xe5, 0xec, 0xe5, 0xff, 0x00, 0x00, 0x00, 0xff, 0xff, 0x01, 0x00, 0x00,
		0xff, 0xff, 0x6f, 0x1d, 0x61, 0x78, 0xcc, 0xb2, 0x03, 0x00,
	}
)


// ΛEnumTypes is a map, keyed by a YANG schema path, of the enumerated types that
// correspond with the leaf. The type is represented as a reflect.Type. The naming
// of the map ensures that there are no clashes with valid YANG identifiers.
var ΛEnumTypes = map[string][]reflect.Type{
	"/waveserver-interfaces/acl/ipv4-acl-entry/properties/action": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_AclAction)(0)),
	},
	"/waveserver-interfaces/acl/ipv6-acl-entry/properties/action": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_AclAction)(0)),
	},
	"/waveserver-interfaces/bgp/peer/name": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_Name)(0)),
	},
	"/waveserver-interfaces/bgp/peer/operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_WaveserverInterfaces_Bgp_Peer_OperationalState)(0)),
	},
	"/waveserver-interfaces/bgp/state/admin-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/bgp/state/operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/inband-if-neighbor-status/ipv4-operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_UpDownEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/inband-if-neighbor-status/ipv6-operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_UpDownEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/properties/ipv4/admin-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/properties/ipv6/gateway-configuration/operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/properties/ipv6/gateway-configuration/source": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_IpAddressType)(0)),
	},
	"/waveserver-interfaces/logical-interface/properties/ipv6/oper-gateway/source": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_IpAddressType)(0)),
	},
	"/waveserver-interfaces/logical-interface/properties/ipv6/oper-ip-address/source": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_IpAddressType)(0)),
	},
	"/waveserver-interfaces/logical-interface/state/admin-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/logical-interface/state/operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_UpDownEnum)(0)),
	},
	"/waveserver-interfaces/physical-interface/id/type": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Id_Type)(0)),
	},
	"/waveserver-interfaces/physical-interface/properties/ethernet/duplex": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Duplex)(0)),
	},
	"/waveserver-interfaces/physical-interface/properties/ethernet/speed": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_WaveserverInterfaces_PhysicalInterface_Properties_Ethernet_Speed)(0)),
	},
	"/waveserver-interfaces/physical-interface/state/admin-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
	"/waveserver-interfaces/physical-interface/state/operational-state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_UpDownEnum)(0)),
	},
	"/waveserver-interfaces/stacks/ipv6-stack-state/preference": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_StackPreference)(0)),
	},
	"/waveserver-interfaces/stacks/ipv6-stack-state/state": []reflect.Type{
		reflect.TypeOf((E_CienaWaveserverInterfaces_EnabledDisabledEnum)(0)),
	},
}

